@@ -26,6 +26,8 @@
 #include <libglom/standard_table_prefs_fields.h>
 #include <libglom/document/document.h>
 #include <libglom/data_structure/glomconversions.h>
+#include <libglom/utils.h>
+#include <libglom/sql_utils.h>
 #include <glom/mode_design/layout/dialog_choose_field.h>
 
 //#ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -41,15 +43,11 @@
 #include <libglom/data_structure/layout/report_parts/layoutitem_summary.h>
 #include <libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
 #include <libglom/data_structure/layout/report_parts/layoutitem_verticalgroup.h>
-#include <libglom/data_structure/layout/report_parts/layoutitem_header.h>
-#include <libglom/data_structure/layout/report_parts/layoutitem_footer.h>
 #include <glom/python_embed/glom_python.h>
 #include <libglom/privs.h>
 #include <libglom/db_utils.h>
 #include <glibmm/i18n.h>
 
-#include <sstream> //For stringstream
-
 #include <libgda/libgda.h> // gda_g_type_from_string
 
 namespace Glom
@@ -745,10 +743,10 @@ bool Base_DB::set_field_value_in_database(const LayoutFieldInRecord& layoutfield
   if(!field_name.empty()) //This should not happen.
   {
     const Gnome::Gda::SqlExpr where_clause = 
-      Utils::build_simple_where_expression(field_in_record.m_table_name,
+      SqlUtils::build_simple_where_expression(field_in_record.m_table_name,
         field_in_record.m_key, field_in_record.m_key_value);
     const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder = 
-      Utils::build_sql_update_with_where_clause(field_in_record.m_table_name,
+      SqlUtils::build_sql_update_with_where_clause(field_in_record.m_table_name,
         field_in_record.m_field, field_value, where_clause);
 
     try //TODO: The exceptions are probably already handled by query_execute(
@@ -824,8 +822,8 @@ Gnome::Gda::Value Base_DB::get_field_value_in_database(const LayoutFieldInRecord
   type_vecConstLayoutFields list_fields;
   auto layout_item = field_in_record.m_field;
   list_fields.emplace_back(layout_item);
-  auto sql_query = Utils::build_sql_select_with_key(field_in_record.m_table_name,
-    list_fields, field_in_record.m_key, field_in_record.m_key_value, type_sort_clause(), 1);
+  auto sql_query = SqlUtils::build_sql_select_with_key(field_in_record.m_table_name,
+    list_fields, field_in_record.m_key, field_in_record.m_key_value, SqlUtils::type_sort_clause(), 1);
 
   auto data_model = DbUtils::query_execute_select(sql_query);
   if(data_model)
@@ -864,10 +862,10 @@ Gnome::Gda::Value Base_DB::get_field_value_in_database(const std::shared_ptr<Fie
   auto layout_item = std::make_shared<LayoutItem_Field>();
   layout_item->set_full_field_details(field);
   list_fields.emplace_back(layout_item);
-  auto sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name,
+  auto sql_query = SqlUtils::build_sql_select_with_where_clause(found_set.m_table_name,
     list_fields,
     found_set.m_where_clause,
-    std::shared_ptr<const Relationship>() /* extra_join */, type_sort_clause(),
+    std::shared_ptr<const Relationship>() /* extra_join */, SqlUtils::type_sort_clause(),
     1 /* limit */);
 
   auto data_model = DbUtils::query_execute_select(sql_query);
@@ -1117,7 +1115,7 @@ bool Base_DB::check_entered_value_for_uniqueness(const Glib::ustring& table_name
 bool Base_DB::check_entered_value_for_uniqueness(const Glib::ustring& table_name, const Gtk::TreeModel::iterator& /* row */,  const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& field_value, Gtk::Window* parent_window)
 {
   //Check whether the value meets uniqueness constraints, if any:
-  const std::shared_ptr<const Field>& field = layout_field->get_full_field_details();
+  const auto field = layout_field->get_full_field_details();
   if(field && (field->get_primary_key() || field->get_unique_key()))
   {
     if(!get_field_value_is_unique(table_name, layout_field, field_value))
@@ -1188,7 +1186,7 @@ bool Base_DB::get_primary_key_is_in_foundset(const FoundSet& found_set, const Gn
     cond_id = eq_id;
 
   auto query =
-    Utils::build_sql_select_with_where_clause(found_set.m_table_name, fieldsToGet,
+    SqlUtils::build_sql_select_with_where_clause(found_set.m_table_name, fieldsToGet,
       builder->export_expression(cond_id));
   auto data_model = DbUtils::query_execute_select(query);
 
@@ -1248,7 +1246,7 @@ void Base_DB::set_found_set_where_clause_for_portal(FoundSet& found_set, const s
   if(where_clause_to_key_field)
   {
     found_set.m_where_clause =
-      Utils::build_simple_where_expression(where_clause_to_table_name, where_clause_to_key_field, foreign_key_value);
+      SqlUtils::build_simple_where_expression(where_clause_to_table_name, where_clause_to_key_field, foreign_key_value);
   }
 }
 
@@ -1279,7 +1277,7 @@ bool Base_DB::disable_user(const Glib::ustring& user)
   if(user.empty())
     return false;
 
-  type_vec_strings vecGroups = Privs::get_groups_of_user(user);
+  const auto vecGroups = Privs::get_groups_of_user(user);
   for(const auto& group : vecGroups)
   {
     DbUtils::remove_user_from_group(user, group);
