@@ -25,6 +25,8 @@
 #include <glom/python_embed/glom_python.h>
 #include <glom/utils_ui.h>
 #include <libglom/db_utils.h>
+#include <libglom/sql_utils.h>
+#include <libglom/utils.h>
 #include <sstream>
 #include <iostream>
 #include <glibmm/i18n.h>
@@ -62,7 +64,7 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
 
   const Glib::ustring primary_key_name = fieldPrimaryKey->get_name();
 
-  type_vecConstLayoutFields fieldsToAdd = m_FieldsShown;
+  auto fieldsToAdd = m_FieldsShown;
   if(m_TableFields.empty())
     m_TableFields = DbUtils::get_fields_for_table(document, m_table_name);
 
@@ -100,7 +102,7 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
       {
         Gnome::Gda::Value value;
 
-        const std::shared_ptr<const Field>& field = layout_item->get_full_field_details();
+        const auto field = layout_item->get_full_field_details();
         if(!field)
           continue;
         
@@ -488,11 +490,11 @@ void Base_DB_Table_Data::refresh_related_fields(const LayoutFieldInRecord& field
   //Get values for lookup fields, if this field triggers those relationships:
   //TODO_performance: There is a LOT of iterating and copying here.
   //const Glib::ustring strFieldName = field_in_record_changed.m_field->get_name();
-  type_vecConstLayoutFields fieldsToGet = get_related_fields(field_in_record_changed.m_field);
+  const auto fieldsToGet = get_related_fields(field_in_record_changed.m_field);
 
   if(!fieldsToGet.empty())
   {
-    auto query = Utils::build_sql_select_with_key(field_in_record_changed.m_table_name, fieldsToGet, field_in_record_changed.m_key, field_in_record_changed.m_key_value);
+    auto query = SqlUtils::build_sql_select_with_key(field_in_record_changed.m_table_name, fieldsToGet, field_in_record_changed.m_key, field_in_record_changed.m_key_value);
     //std::cout << "debug: " << G_STRFUNC << ": query=" << query << std::endl;
 
     auto result = DbUtils::query_execute_select(query);
@@ -508,13 +510,13 @@ void Base_DB_Table_Data::refresh_related_fields(const LayoutFieldInRecord& field
       {
         auto iterFields = fieldsToGet.begin();
 
-        const guint cols_count = result->get_n_columns();
+        const auto cols_count = result->get_n_columns(); // -1 means unknown
         if(cols_count <= 0)
         {
           std::cerr << G_STRFUNC << ": The result had 0 columns\n";
         }
 
-        for(guint uiCol = 0; uiCol < cols_count; ++uiCol)
+        for(int uiCol = 0; uiCol < cols_count; ++uiCol)
         {
           const auto value = result->get_value_at(uiCol, 0 /* row */);
           auto layout_item = *iterFields;
