@@ -32,6 +32,7 @@
 #include <libglom/init.h>
 #include <libglom/privs.h>
 #include <libglom/db_utils.h>
+#include <libglom/file_utils.h>
 #include <libglom/utils.h>
 #include <giomm/file.h>
 #include <glibmm/optioncontext.h>
@@ -376,11 +377,11 @@ int main(int argc, char* argv[])
 
   //Save a copy, specifying the path to file in a directory:
   filepath_dir = 
-    Glom::Utils::get_file_path_without_extension(
+    Glom::FileUtils::get_file_path_without_extension(
       Glib::build_filename(
         group.m_arg_filepath_dir_output,
         group.m_arg_filepath_name_output));
-  const std::string filepath =
+  const auto filepath =
     Glib::build_filename(filepath_dir, group.m_arg_filepath_name_output);
 
   //Make sure that the file does not exist yet:
@@ -496,7 +497,7 @@ int main(int argc, char* argv[])
   }
         
   //Startup. For instance, create the self-hosting files if necessary:
-  const Glom::ConnectionPool::InitErrors initialized_errors =
+  const auto initialized_errors =
     connection_pool->initialize( sigc::ptr_fun(&on_initialize_progress) );
   g_assert(initialized_errors == Glom::ConnectionPool::Backend::InitErrors::NONE);
 
