@@ -134,7 +134,7 @@ public:
 
   /** Do not actually connect to the database,
    * but create a Gnome::Gda::Connection object
-   * just so that utility functions such as Utils::sqlbuilder_get_full_query()
+   * just so that utility functions such as SqlUtils::sqlbuilder_get_full_query()
    * and DbUtils::escape_sql_id() can work.
    */
   void set_fake_connection();
@@ -339,7 +339,7 @@ private:
   Gtk::Dialog* m_dialog_epc_progress; //For progress while generating certificates.
 
   std::shared_ptr<Backend> m_backend;
-  Glib::RefPtr<Gnome::Gda::Connection> m_refGdaConnection;
+  Glib::RefPtr<Gnome::Gda::Connection> m_gda_connection;
   guint m_sharedconnection_refcount;
   bool m_ready_to_connect;
   Glib::ustring m_user, m_password, m_database;
