@@ -19,12 +19,9 @@
  */
 
 #include <libglom/connectionpool_backends/mysql_self.h>
-#include <libglom/connectionpool.h>
 #include <libglom/utils.h>
-#include <libglom/db_utils.h>
 #include <libglom/spawn_with_feedback.h>
 #include <giomm/file.h>
-#include <glib/gstdio.h> // For g_remove
 
 #include <glibmm/convert.h>
 #include <glibmm/fileutils.h>
@@ -33,9 +30,7 @@
 #include <glibmm/timer.h>
 #include <glibmm/main.h>
 #include <glibmm/shell.h>
-#include <glibmm/i18n.h>
-
-#include <sstream> //For stringstream
+#include <glibmm/i18n-lib.h>
 #include <iostream>
 
 #ifdef G_OS_WIN32
@@ -48,8 +43,6 @@
 # include <netinet/in.h> //For sockaddr_in
 #endif
 
-#include <signal.h> //To catch segfaults
-
 // Uncomment to see debug messages
 //#define GLOM_CONNECTION_DEBUG
 
