@@ -18,8 +18,7 @@
  * Boston, MA 02110-1301 USA.
  */
 
-#include "config.h" // For POSTGRES_UTILS_PATH
-#include <libglom/libglom_config.h>
+#include <libglom/libglom_config.h> // For POSTGRES_UTILS_PATH
 
 #include <libglom/connectionpool_backends/postgres.h>
 #include <libglom/spawn_with_feedback.h>
@@ -32,7 +31,6 @@
 #include <glibmm/miscutils.h>
 #include <glibmm/shell.h>
 #include <glib/gstdio.h> /* For g_rename(). TODO: Wrap this in glibmm? */
-#include <glibmm/i18n.h>
 
 #include <iostream>
 
