@@ -19,9 +19,9 @@
  */
 
 #include <libglom/connectionpool_backends/postgres_self.h>
-#include <libglom/connectionpool.h>
 #include <libglom/utils.h>
 #include <libglom/db_utils.h>
+#include <libglom/file_utils.h>
 #include <libglom/spawn_with_feedback.h>
 #include <giomm/file.h>
 #include <glib/gstdio.h> // For g_remove
@@ -31,9 +31,6 @@
 #include <glibmm/stringutils.h>
 #include <glibmm/main.h>
 #include <glibmm/shell.h>
-#include <glibmm/i18n.h>
-
-#include <sstream> //For stringstream
 #include <iostream>
 #include <regex>
 
@@ -213,7 +210,7 @@ Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_prog
   // initdb creates a new postgres database cluster:
 
   //Get file:// URI for the tmp/ directory:
-  const auto temp_pwfile = Utils::get_temp_file_path("glom_initdb_pwfile");
+  const auto temp_pwfile = FileUtils::get_temp_file_path("glom_initdb_pwfile");
   const auto temp_pwfile_uri = Glib::filename_to_uri(temp_pwfile);
   const auto pwfile_creation_succeeded = create_text_file(temp_pwfile_uri, password);
   g_assert(pwfile_creation_succeeded);
@@ -224,7 +221,7 @@ Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_prog
   // from being based on the current environment, because we want the database to be
   // as portable as possible.
   // See http://www.postgresql.org/docs/current/static/app-initdb.html
-  const std::string command_initdb = get_path_to_postgres_executable("initdb") +
+  const auto command_initdb = get_path_to_postgres_executable("initdb") +
     " -D " + Glib::shell_quote(dbdir_data) +
     " -U " + initial_username +
     " --pwfile=" + Glib::shell_quote(temp_pwfile) +
@@ -468,21 +465,7 @@ bool PostgresSelfHosted::set_network_shared(const SlotProgress& /* slot_progress
 
   m_network_shared = network_shared;
 
-  const auto dbdir_uri = m_database_directory_uri;
-
-  std::string dbdir;
-  try
-  {
-    dbdir = Glib::filename_from_uri(dbdir_uri);
-  }
-  catch(const Glib::ConvertError& ex)
-  {
-    std::cerr << G_STRFUNC << "Glib::filename_from_uri() failed: " << ex.what() << std::endl;
-
-    return false;
-  }
-
-  const std::string dbdir_uri_config = dbdir_uri + "/config";
+  const std::string dbdir_uri_config = m_database_directory_uri + "/config";
   const char* default_conf_contents = nullptr;
 
   // Choose the configuration contents based on 
