@@ -23,8 +23,9 @@
 #include <libglom/connectionpool.h>
 #include <libglom/data_structure/glomconversions.h>
 #include <libglom/utils.h>
+#include <libglom/string_utils.h>
 #include <libgda/gda-blob-op.h>
-#include <glibmm/i18n.h>
+#include <glibmm/i18n-lib.h>
 
 #include <iostream>
 
@@ -300,7 +301,7 @@ Glib::ustring Field::to_file_format(const Gnome::Gda::Value& value, glom_field_t
         return Glib::ustring();
       else
       {
-        if(!gda_blob_op_read_all(const_cast<GdaBlobOp*>(gdablob->op), const_cast<GdaBlob*>(gdablob)))
+        if(!gda_blob_op_read_all(gdablob->op, const_cast<GdaBlob*>(gdablob)))
         {
           return Glib::ustring();
         }
@@ -761,7 +762,7 @@ Field::type_map_type_names Field::get_usable_type_names()
 {
   init_map();
 
-  type_map_type_names result =  m_map_type_names_ui;
+  auto result =  m_map_type_names_ui;
 
   //Remove INVALID, because it's not something that a user can use for a field type.
   auto iter = result.find(glom_field_type::INVALID);
