@@ -22,8 +22,8 @@
 #include <libglom/libglom_config.h> // For HAVE_STRPTIME
 
 #include <libglom/data_structure/glomconversions.h>
-#include <libglom/connectionpool.h>
 #include <libglom/utils.h>
+#include <libglom/string_utils.h>
 
 #include <glibmm/convert.h>
 #include <sstream> //For stringstream
@@ -33,9 +33,8 @@
 #include <iostream>   // for cout, endl
 #include <iomanip>
 #include <string.h> // for strlen, memset, strcmp
-#include <stdexcept>
 
-#include <glibmm/i18n.h>
+#include <glibmm/i18n-lib.h>
 
 namespace Glom
 {
