@@ -18,11 +18,10 @@
  * Boston, MA 02110-1301 USA.
  */
 
+#include <libglom/libglom_config.h>
 #include <libglom/data_structure/layout/layoutgroup.h>
-#include <libglom/data_structure/layout/layoutitem_field.h>
-#include <libglom/data_structure/layout/layoutitem_portal.h>
 #include <libglom/algorithms_utils.h>
-#include <glibmm/i18n.h>
+#include <glibmm/i18n-lib.h>
 #include <iostream> 
 
 namespace Glom
@@ -165,9 +164,7 @@ LayoutGroup::type_list_const_items LayoutGroup::get_items() const
 {
   //Get a const map from the non-const map:
   //TODO_Performance: Surely we should not need to copy the structure just to constize it?
-  type_list_const_items result;
-  Utils::copy(m_list_items, result);
-  return result;
+  return Utils::const_list(m_list_items);
 }
 
 LayoutGroup::type_list_const_items LayoutGroup::get_items_recursive() const
