@@ -20,8 +20,8 @@
 
 #include <libglom/data_structure/layout/layoutitem_image.h>
 #include <libglom/utils.h>
-#include <libglom/data_structure/glomconversions.h>
-#include <glibmm/i18n.h>
+#include <libglom/file_utils.h>
+#include <glibmm/i18n-lib.h>
 
 namespace Glom
 {
@@ -83,7 +83,7 @@ void LayoutItem_Image::set_image(const Gnome::Gda::Value& image)
 
 Glib::ustring LayoutItem_Image::create_local_image_uri() const
 {
-  return Utils::create_local_image_uri(m_image);
+  return FileUtils::create_local_image_uri(m_image);
 }
 
 } //namespace Glom
