@@ -22,8 +22,9 @@
  *   Boston, MA  02110-1301, USA.
  */
 
+#include <libglom/libglom_config.h>
 #include <libglom/data_structure/layout/layoutitem_placeholder.h>
-#include <glibmm/i18n.h>
+#include <glibmm/i18n-lib.h>
 
 namespace Glom
 {
