@@ -20,6 +20,7 @@
 
 #include <libglom/algorithms_utils.h>
 #include <libglom/db_utils.h>
+#include <libglom/sql_utils.h>
 #include <libglom/connectionpool.h>
 #include <libglom/data_structure/glomconversions.h>
 #include <libglom/connectionpool_backends/postgres_central.h>
@@ -30,7 +31,8 @@
 #include <libgdamm/metastore.h>
 #include <glibmm/timer.h>
 #include <libgda/libgda.h> // For gda_g_type_from_string
-#include <glibmm/i18n.h>
+#include "string_utils.h"
+#include <glibmm/i18n-lib.h>
 
 
 #include <iostream>
@@ -386,7 +388,7 @@ SystemPrefs get_database_preferences(const std::shared_ptr<const Document>& docu
     bool succeeded = true;
     try
     {
-      //const std::string full_query = Utils::sqlbuilder_get_full_query(builder);
+      //const std::string full_query = SqlUtils::sqlbuilder_get_full_query(builder);
       auto datamodel = query_execute_select(builder);
       if(datamodel && (datamodel->get_n_rows() != 0))
       {
@@ -982,7 +984,7 @@ type_vec_fields get_fields_for_table(const std::shared_ptr<const Document>& docu
     return type_vec_fields(); //This should never happen.
   }
 
-  type_vec_fields result = document->get_table_fields(table_name);
+  const auto result = document->get_table_fields(table_name);
 
   //Look at each field in the database:
   /*
@@ -1040,7 +1042,7 @@ std::shared_ptr<Field> get_fields_for_table_one_field(const std::shared_ptr<cons
   if(field_name.empty() || table_name.empty())
     return result;
 
-  type_vec_fields fields = get_fields_for_table(document, table_name); //TODO_Performance
+  const auto fields = get_fields_for_table(document, table_name); //TODO_Performance
   auto iter = find_if_same_name(fields, field_name);
   if(iter != fields.end()) //TODO: Handle error?
   {
@@ -1518,7 +1520,7 @@ static void recalculate_next_auto_increment_value(const Glib::ustring& table_nam
     if(Glom::Conversions::value_is_empty(value_max))
     {
       std::cerr << G_STRFUNC << ": The MAX() value is null for query: " <<
-        Utils::sqlbuilder_get_full_query(builder) << std::endl;
+        SqlUtils::sqlbuilder_get_full_query(builder) << std::endl;
     }
 
     double num_max = Conversions::get_double_for_gda_value_numeric(value_max);
@@ -1639,13 +1641,13 @@ bool insert_example_data(const std::shared_ptr<const Document>& document, const
     //the query, and allow us to set their values.
 
     //std::cout << G_STRFUNC << ": debug: INSERT query: \n"
-    //  << "    " << Utils::sqlbuilder_get_full_query(builder) << std::endl;
+    //  << "    " << SqlUtils::sqlbuilder_get_full_query(builder) << std::endl;
 
     insert_succeeded = query_execute(builder);
     if(!insert_succeeded)
     {
       std::cerr << G_STRFUNC << ": The INSERT query failed: " <<
-        Utils::sqlbuilder_get_full_query(builder) << std::endl;
+        SqlUtils::sqlbuilder_get_full_query(builder) << std::endl;
       break;
     }
   }
@@ -1676,7 +1678,7 @@ Glib::RefPtr<Gnome::Gda::DataModel> query_execute_select(const Glib::RefPtr<cons
   //Debug output:
   if(builder && ConnectionPool::get_instance()->get_show_debug_output())
   {
-    const auto full_query = Utils::sqlbuilder_get_full_query(builder);
+    const auto full_query = SqlUtils::sqlbuilder_get_full_query(builder);
     std::cout << "debug: " << G_STRFUNC << ":  " << full_query << std::endl;
   }
 
@@ -1718,7 +1720,7 @@ Glib::RefPtr<Gnome::Gda::DataModel> query_execute_select(const Glib::RefPtr<cons
 
   if(!result)
   {
-    const auto full_query = Utils::sqlbuilder_get_full_query(builder);
+    const auto full_query = SqlUtils::sqlbuilder_get_full_query(builder);
     std::cerr << G_STRFUNC << ": Error while executing SQL: "
       << std::endl << "  " << full_query << std::endl << std::endl;
     handle_error();
@@ -1803,7 +1805,7 @@ bool query_execute(const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& builder)
   //Debug output:
   if(builder && ConnectionPool::get_instance()->get_show_debug_output())
   {
-    const auto full_query = Utils::sqlbuilder_get_full_query(builder);
+    const auto full_query = SqlUtils::sqlbuilder_get_full_query(builder);
     std::cerr << G_STRFUNC << ": " << full_query << std::endl;
   }
 
@@ -1816,21 +1818,21 @@ bool query_execute(const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& builder)
   catch(const Gnome::Gda::ConnectionError& ex)
   {
     std::cerr << G_STRFUNC << ": " << ex.what() << std::endl;
-    const auto full_query = Utils::sqlbuilder_get_full_query(builder);
+    const auto full_query = SqlUtils::sqlbuilder_get_full_query(builder);
     std::cerr << G_STRFUNC << ":   full_query: " << full_query << std::endl;
     return false;
   }
   catch(const Gnome::Gda::ServerProviderError& ex)
   {
     std::cerr << G_STRFUNC << ": code=" << ex.code() << "message=" << ex.what() << std::endl;
-    const auto full_query = Utils::sqlbuilder_get_full_query(builder);
+    const auto full_query = SqlUtils::sqlbuilder_get_full_query(builder);
     std::cerr << G_STRFUNC << ":   full_query: " << full_query << std::endl;
     return false;
   }
   catch(const Gnome::Gda::SqlError& ex) //TODO: Make sure that statement_execute_non_select_builder() is documented as throwing this.
   {
     std::cerr << G_STRFUNC << ": " << ex.what() << std::endl;
-    const auto full_query = Utils::sqlbuilder_get_full_query(builder);
+    const auto full_query = SqlUtils::sqlbuilder_get_full_query(builder);
     std::cerr << G_STRFUNC << ":   full_query: " << full_query << std::endl;
     return false;
   }
@@ -1906,10 +1908,17 @@ Glib::ustring get_unused_database_name(const Glib::ustring& base_name)
   if(!connection_pool)
     return Glib::ustring();
 
-  bool keep_trying = true;
+  int count_tries = 0;
   size_t extra_num = 0;
-  while(keep_trying)
+  while(true)
   {
+    if (count_tries > 200) {
+      std::cerr << G_STRFUNC << ": Too many attempts failed.\n";
+      return Glib::ustring();
+    }
+
+    count_tries++;
+
     Glib::ustring database_name_possible;
     if(extra_num == 0)
     {
@@ -1934,6 +1943,8 @@ Glib::ustring get_unused_database_name(const Glib::ustring& base_name)
 
     std::shared_ptr<Glom::SharedConnection> connection;
 
+    //We try this until it fails,
+    //knowing that it will fail eventually.
     try
     {
       connection = ConnectionPool::get_and_connect();
@@ -1968,7 +1979,7 @@ int count_rows_returned_by(const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& sql
   }
 
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder =
-    Utils::build_sql_select_count_rows(sql_query);
+    SqlUtils::build_sql_select_count_rows(sql_query);
 
   int result = 0;
 
@@ -2183,7 +2194,7 @@ bool add_group(const std::shared_ptr<const Document>& document, const Glib::ustr
   priv.m_view = true;
   priv.m_edit = true;
 
-  const type_vec_strings table_list =
+  const auto table_list =
     get_table_names_from_database(true /* plus system prefs */);
   for(const auto& table : table_list)
   {
@@ -2313,7 +2324,7 @@ type_map_fields get_record_field_values(const std::shared_ptr<const Document>& d
   {
     //sharedptr<const Field> fieldPrimaryKey = get_field_primary_key();
 
-    auto query = Utils::build_sql_select_with_key(table_name, fieldsToGet, primary_key, primary_key_value);
+    auto query = SqlUtils::build_sql_select_with_key(table_name, fieldsToGet, primary_key, primary_key_value);
 
     Glib::RefPtr<const Gnome::Gda::DataModel> data_model;
     try
@@ -2363,6 +2374,133 @@ type_map_fields get_record_field_values(const std::shared_ptr<const Document>& d
   return field_values;
 }
 
+
+type_list_values_with_second get_choice_values_all(const std::shared_ptr<const Document>& document, const std::shared_ptr<const LayoutItem_Field>& field)
+{
+  return get_choice_values(document, field,
+                           Gnome::Gda::Value() /* means get all with no WHERE clause */);
+}
+
+type_list_values_with_second get_choice_values(const std::shared_ptr<const Document>& document, const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& foreign_key_value)
+{
+  //TODO: Reduce duplication between this and get_choice_values(field).
+
+  type_list_values_with_second result;
+
+  //We allows this, so this method can be used to get all records in a related table:
+  /*
+  if(Conversions::value_is_empty(foreign_key_value))
+  {
+    std::cout << G_STRFUNC << "debug: foreign_key_value is empty.\n";
+    return result;
+  }
+  */
+
+  const Formatting& format = field->get_formatting_used();
+  std::shared_ptr<const Relationship> choice_relationship;
+  std::shared_ptr<const LayoutItem_Field> layout_choice_first;
+  std::shared_ptr<const LayoutGroup> layout_choice_extra;
+  Formatting::type_list_sort_fields choice_sort_fields;
+  bool choice_show_all = false;
+  format.get_choices_related(choice_relationship, layout_choice_first, layout_choice_extra, choice_sort_fields, choice_show_all);
+
+  if(!choice_relationship)
+  {
+    std::cerr << G_STRFUNC << ": !choice_relationship.\n";
+    return result;
+  }
+
+  SqlUtils::type_vecConstLayoutFields fields;
+  fields.emplace_back(layout_choice_first);
+
+  if(layout_choice_extra)
+  {
+    for(const auto& item : layout_choice_extra->get_items_recursive())
+    {
+      const auto& item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
+      if(item_field)
+        fields.emplace_back(item_field); //TODO: Don't ignore other usable items such as static text.
+    }
+  }
+
+  const Glib::ustring to_table = choice_relationship->get_to_table();
+  const auto to_field = document->get_field(to_table, choice_relationship->get_to_field());
+
+  if(!to_field)
+  {
+    std::cerr << G_STRFUNC << ": to_field is null.\n";
+  }
+
+  //Default to some sort order rather than none:
+  if(choice_sort_fields.empty())
+  {
+    choice_sort_fields.emplace_back( Formatting::type_pair_sort_field(layout_choice_first, true /* ascending */));
+  }
+
+  //TODO: Support related relationships (in the UI too):
+  auto builder = SqlUtils::build_sql_select_with_key(
+          to_table,
+          fields,
+          to_field,
+          foreign_key_value,
+          choice_sort_fields);
+
+  if(!builder)
+  {
+    std::cerr << G_STRFUNC << ": builder is null.\n";
+    return result;
+  }
+
+  //TODO: builder->select_order_by(choice_field_id);
+
+  //Connect to database and get the related values:
+  auto connection = ConnectionPool::get_instance()->connect();
+
+  if(!connection)
+  {
+    std::cerr << G_STRFUNC << ": connection is null.\n";
+    return result;
+  }
+
+  const auto sql_query =
+          SqlUtils::sqlbuilder_get_full_query(builder);
+  //std::cout << "debug: sql_query=" << sql_query << std::endl;
+  auto datamodel = connection->get_gda_connection()->statement_execute_select(sql_query);
+
+  if(datamodel)
+  {
+    const auto count = datamodel->get_n_rows(); // -1 means unknown
+    const auto cols_count = datamodel->get_n_columns(); // -1 means unknown
+    for(int row = 0; row < count; ++row)
+    {
+
+      std::pair<Gnome::Gda::Value, type_list_values> itempair;
+      itempair.first = datamodel->get_value_at(0, row);
+
+      if(layout_choice_extra && (cols_count > 1))
+      {
+        type_list_values list_values;
+        for(int i = 1; i < cols_count; ++i)
+        {
+          list_values.emplace_back(datamodel->get_value_at(i, row));
+        }
+
+        itempair.second = list_values;
+      }
+
+      result.emplace_back(itempair);
+    }
+  }
+  else
+  {
+    std::cerr << G_STRFUNC << ": Error while executing SQL\n" <<
+    "  " <<  sql_query << std::endl;
+    return result;
+  }
+
+  return result;
+}
+
 } //namespace DbUtils
 
 } //namespace Glom
