@@ -16,7 +16,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "config.h"
+#include <libglom/libglom_config.h>
 #include <libglom/document/bakery/document.h>
 #include <libglom/utils.h>
 #include <giomm/file.h>
@@ -30,10 +30,10 @@ const guint BYTES_TO_PROCESS = 256;
 
 Document::Document()
 {
-  m_bIsNew = true;
-  m_bModified = false;
-  m_bReadOnly = false;
-  m_pView = nullptr;
+  m_is_new = true;
+  m_modified = false;
+  m_read_only = false;
+  m_view = nullptr;
 }
 
 Document::~Document()
@@ -93,22 +93,22 @@ Glib::ustring Document::get_contents() const
   return m_strContents;
 }
 
-void Document::set_modified(bool bVal /* = true */)
+void Document::set_modified(bool value /* = true */)
 {
-  m_bModified = bVal;
+  m_modified = value;
 
-  if(m_bModified)
+  if(m_modified)
   {
-    m_bIsNew = false; //Can't be new if it's been modified.
+    m_is_new = false; //Can't be new if it's been modified.
   }
 
   //Allow the application or view to update it's UI accordingly:
-  signal_modified().emit(m_bModified);
+  signal_modified().emit(m_modified);
 }
 
 bool Document::get_modified() const
 {
-  return m_bModified;
+  return m_modified;
 }
 
 bool Document::load(int& failure_code)
@@ -123,8 +123,8 @@ bool Document::load(int& failure_code)
     if(bTest)
     {
       //Tell the View to show the new data:
-      if(m_pView)
-        m_pView->load_from_document();
+      if(m_view)
+        m_view->load_from_document();
     }
   }
 
@@ -157,8 +157,8 @@ bool Document::load_from_data(const guchar* data, std::size_t length, int& failu
   if(bTest)
   {
     //Tell the View to show the new data:
-    if(m_pView)
-      m_pView->load_from_document();
+    if(m_view)
+      m_view->load_from_document();
   }
 
   set_is_new(false);
@@ -181,8 +181,8 @@ bool Document::load_after(int& failure_code)
 bool Document::save()
 {
   //Tell the view to update the data in this document.
-  if(m_pView)
-    m_pView->save_to_document();
+  if(m_view)
+    m_view->save_to_document();
 
   const auto bTest = save_before(); //This could be overridden.
   if(bTest)
@@ -235,7 +235,6 @@ bool Document::read_from_disk(int& failure_code)
 
   // Read data from the input uri:
   guint buffer[BYTES_TO_PROCESS] = {0, }; // For each chunk.
-  gsize bytes_read = 0;
   std::string data; //We use a std::string because we might not get whole UTF8 characters at a time. This might not be necessary.
 
   try
@@ -243,13 +242,14 @@ bool Document::read_from_disk(int& failure_code)
     bool bContinue = true;
     while(bContinue)
     {
-      bytes_read = stream->read(buffer, BYTES_TO_PROCESS);
+      auto bytes_read = stream->read(buffer, BYTES_TO_PROCESS);
 
       if(bytes_read == 0)
         bContinue = false; //stop because we reached the end.
       else
       {
         // Add the text to the string:
+        // TODO_Performance: Avoid reallocations.
         data += std::string((char*)buffer, bytes_read);
       }
     }
@@ -427,17 +427,17 @@ Glib::ustring Document::util_file_uri_get_name(const Glib::ustring& file_uri, co
 
 void Document::set_view(ViewBase* pView)
 {
-  m_pView = pView;
+  m_view = pView;
 }
 
 ViewBase* Document::get_view()
 {
-  return m_pView;
+  return m_view;
 }
 
 bool Document::get_read_only() const
 {
-  if(m_bReadOnly)
+  if(m_read_only)
   {
     //An application might have used set_read_only() to make this document explicitly read_only, regardless of the positions of the storage location.
     return true;
@@ -468,22 +468,22 @@ bool Document::get_read_only() const
   }
 }
 
-void Document::set_read_only(bool bVal)
+void Document::set_read_only(bool value)
 {
-  m_bReadOnly = bVal;
+  m_read_only = value;
 }
 
 bool Document::get_is_new() const
 {
-  return m_bIsNew;
+  return m_is_new;
 }
 
-void Document::set_is_new(bool bVal)
+void Document::set_is_new(bool value)
 {
-  if(bVal)
+  if(value)
     set_modified(false); //can't be modified if it is new.
 
-  m_bIsNew = bVal;
+  m_is_new = value;
 }
 
 void Document::set_file_extension(const Glib::ustring& strVal)
