@@ -61,14 +61,14 @@ public:
   void setitem(const boost::python::object& /* key */, const boost::python::object& /* value */);
 
   void set_fields(const PyGlomRecord::type_map_field_values& field_values,
-    const Document* document,
+    const std::shared_ptr<const Document>& document,
     const Glib::ustring& table_name,
     const std::shared_ptr<const Field>& key_field,
     const Gnome::Gda::Value& key_field_value,
     const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection);
 
 public:
-  const Document* m_document;
+  std::shared_ptr<const Document> m_document;
   Glib::ustring m_table_name;
   type_map_field_values m_map_field_values;
 private:
