@@ -22,11 +22,13 @@
 #include <libglom/utils.h>
 #include <libglom/data_structure/glomconversions.h>
 #include <libglom/db_utils.h>
+#include <libglom/file_utils.h>
+#include <libglom/sql_utils.h>
 #include <libglom/xsl_utils.h>
 #include <libglom/xml_utils.h>
 #include <iostream>
 #include <glibmm/miscutils.h>
-#include <glibmm/i18n.h>
+#include <glibmm/i18n-lib.h>
 
 namespace Glom
 {
@@ -240,8 +242,8 @@ bool ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
     }
     else
     {
-      const guint rows_count = datamodel->get_n_rows();
-      for(guint row = 0; row < rows_count; ++row)
+      const auto rows_count = datamodel->get_n_rows(); // -1 means unknown.
+      for(int row = 0; row < rows_count; ++row)
       {
         const auto group_value = datamodel->get_value_at(0 /* col*/, row); //TODO: Catch exceptions.
 
@@ -256,11 +258,11 @@ bool ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
 
         //TODO: Use a SQL parameter instead of using sql().
         Gnome::Gda::SqlExpr where_clause =
-          Utils::build_simple_where_expression(group_field_table_name, field_group_by->get_full_field_details(), group_value);
+          SqlUtils::build_simple_where_expression(group_field_table_name, field_group_by->get_full_field_details(), group_value);
 
         if(!found_set_parent.m_where_clause.empty())
         {
-          where_clause = Utils::build_combined_where_expression(where_clause, found_set_parent.m_where_clause,
+          where_clause = SqlUtils::build_combined_where_expression(where_clause, found_set_parent.m_where_clause,
             Gnome::Gda::SQL_OPERATOR_TYPE_AND);
         }
 
@@ -272,7 +274,7 @@ bool ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
         {
           auto nodeSecondaryFields = nodeGroupBy->add_child_element("secondary_fields");
 
-          type_vecLayoutItems itemsToGet =
+          const auto itemsToGet =
             copy_with_cloned_items(group_by->get_secondary_fields()->m_list_items);
 
           if(!itemsToGet.empty())
@@ -349,7 +351,7 @@ bool ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
     }
 
     //Get list of fields to get from the database.
-    Utils::type_vecLayoutFields fieldsToGet;
+    SqlUtils::type_vecLayoutFields fieldsToGet;
     for(const auto& layout_item : items)
     {
       auto layoutitem_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
@@ -375,7 +377,7 @@ bool ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
     if(one_record_only)
       limit = 1;
 
-    auto sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name,
+    auto sql_query = SqlUtils::build_sql_select_with_where_clause(found_set.m_table_name,
       fieldsToGet,
       found_set.m_where_clause, std::shared_ptr<const Relationship>() /* extra_join */, found_set.m_sort_clause,
       limit);
@@ -388,9 +390,9 @@ bool ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
     }
     else
     {
-      const guint rows_count = datamodel->get_n_rows();
+      const auto rows_count = datamodel->get_n_rows();
 
-      for(guint row = 0; row < rows_count; ++row)
+      for(int row = 0; row < rows_count; ++row)
       {
         auto nodeRow = parent_node.add_child_element("row");
 
@@ -483,7 +485,7 @@ bool ReportBuilder::report_build_records_field(const FoundSet& found_set, xmlpp:
 
   //Handle the value:
   if(field_type == Field::glom_field_type::IMAGE)
-     nodeField->set_attribute("image_uri", Utils::create_local_image_uri(value));
+     nodeField->set_attribute("image_uri", FileUtils::create_local_image_uri(value));
   else
   {
     Glib::ustring text_value = Conversions::get_text_for_gda_value(field_type, value, m_locale, field->get_formatting_used().m_numeric_format);
@@ -578,7 +580,7 @@ std::string ReportBuilder::report_build_and_save(const FoundSet& found_set, cons
   const auto contents = report_build(found_set, report);
 
  //Save it to a temporary file and show it in a browser:
-  const auto temp_uri = Utils::get_temp_file_uri("glom_printout", "html");
+  const auto temp_uri = FileUtils::get_temp_file_uri("glom_printout", "html");
   std::cout << G_STRFUNC << ": temp_uri=" << temp_uri << std::endl;
 
   auto file = Gio::File::create_for_uri(temp_uri);
