@@ -22,12 +22,9 @@
 #include <libglom/spawn_with_feedback.h>
 #include <glibmm/main.h>
 #include <glibmm/spawn.h>
-#include <glibmm/iochannel.h>
 #include <glibmm/shell.h>
 #include <glibmm/fileutils.h>
 #include <glibmm/miscutils.h>
-#include <glibmm/i18n.h>
-#include <memory> //For shared_ptr.
 #include <stdexcept>
 #include <iostream>
 
@@ -189,8 +186,8 @@ public:
     try
     {
       std::vector<std::string> arguments = Glib::shell_parse_argv(command_line);
-      int child_stdout;
-      int child_stderr;
+      int child_stdout = 0;
+      int child_stderr = 0;
       Glib::spawn_async_with_pipes(Glib::get_current_dir(), arguments, Glib::SPAWN_DO_NOT_REAP_CHILD, sigc::slot<void>(), &pid, 0, (redirect & REDIRECT_STDOUT) ? &child_stdout : 0, (redirect & REDIRECT_STDERR) ? &child_stderr : 0);
       if(redirect & REDIRECT_STDOUT)
         redirect_to_string(child_stdout, stdout_text);
