@@ -31,8 +31,7 @@
 #include <glom/libglom/init.h>
 #include <glom/libglom/connectionpool.h>
 #include <glom/libglom/utils.h>
-
-#include <giomm/file.h>
+#include <libglom/file_utils.h>
 #include <glibmm/convert.h>
 #include <glibmm/miscutils.h>
 
@@ -254,7 +253,7 @@ bool check_postgres_is_available_with_warning()
   if(!binpath.empty())
   {
     const auto uri_binpath = Glib::filename_to_uri(binpath);
-    if(Utils::file_exists(uri_binpath))
+    if(FileUtils::file_exists(uri_binpath))
       return true;
   }
 
@@ -309,7 +308,7 @@ bool check_mysql_is_available_with_warning()
   if(!binpath.empty())
   {
     const auto uri_binpath = Glib::filename_to_uri(binpath);
-    if(Utils::file_exists(uri_binpath))
+    if(FileUtils::file_exists(uri_binpath))
       return true;
   }
 
