@@ -23,8 +23,9 @@
 #include <glom/utils_ui.h>
 #include <glom/appwindow.h>
 #include <libglom/data_structure/glomconversions.h>
+#include <libglom/sql_utils.h>
 #include <libglom/db_utils.h>
-#include <glom/frame_glom.h> //For show_ok_dialog()
+#include <libglom/utils.h>
 #include <glom/glade_utils.h>
 #include <giomm/menu.h>
 #include <glibmm/i18n.h>
@@ -71,40 +72,16 @@ void Box_Data_Calendar_Related::enable_buttons()
   //m_calendar.set_allow_view_details(view_details_possible); //Don't allow the user to go to a record in a hidden table.
 }
 
-bool Box_Data_Calendar_Related::init_db_details(const std::shared_ptr<const LayoutItem_Portal>& portal, bool show_title)
+void Box_Data_Calendar_Related::show_title_in_ui(const Glib::ustring& title)
 {
-  //This calls the other method overload:
-  return Box_Data_Portal::init_db_details(portal, show_title);
-}
-
-bool Box_Data_Calendar_Related::init_db_details(const Glib::ustring& parent_table, bool show_title)
-{
-  //std::cout << "debug: " << G_STRFUNC << ": " << parent_table << std::endl;
-
-  m_parent_table = parent_table;
-
-  if(m_portal)
-    LayoutWidgetBase::m_table_name = m_portal->get_table_used(Glib::ustring() /* parent table_name, not used. */);
-  else
-    LayoutWidgetBase::m_table_name = Glib::ustring();
-
-  Base_DB_Table::m_table_name = LayoutWidgetBase::m_table_name;
-
-  //TODO: This is duplicated in box_data_related_list.cc and box_data_portal.cc. Just use code from the base class?
-  if(show_title)
-  {
-    Glib::ustring title;
-    if(m_portal)
-      title = item_get_title(m_portal);
-
+  if (!title.empty()) {
     m_Label.set_markup(UiUtils::bold_message(title));
     m_Label.show();
 
     m_calendar.set_margin_start(Utils::to_utype(UiUtils::DefaultSpacings::LARGE));
     m_calendar.set_margin_top(Utils::to_utype(UiUtils::DefaultSpacings::SMALL));
   }
-  else
-  {
+  else {
     m_Label.set_markup(Glib::ustring());
     m_Label.hide();
 
@@ -112,24 +89,8 @@ bool Box_Data_Calendar_Related::init_db_details(const Glib::ustring& parent_tabl
     m_calendar.set_margin_start(0);
     m_calendar.set_margin_top(0);
   }
-
-  if(m_portal)
-  {
-    auto document = get_document();    
-    m_key_field = DbUtils::get_fields_for_table_one_field(document,
-      LayoutWidgetBase::m_table_name, m_portal->get_to_field_used());
-  }
-  else
-    m_key_field.reset();
-
-  enable_buttons();
-
-  FoundSet found_set;
-  found_set.m_table_name = LayoutWidgetBase::m_table_name;
-  return Box_Data::init_db_details(found_set, "" /* layout_platform */); //Calls create_layout() and fill_from_database().
 }
 
-
 void Box_Data_Calendar_Related::create_layout()
 {
   Box_Data::create_layout();
@@ -139,7 +100,8 @@ void Box_Data_Calendar_Related::create_layout()
 
 bool Box_Data_Calendar_Related::fill_from_database()
 {
-  if(!m_portal)
+  const auto portal = get_portal();
+  if(!portal)
     return false;
 
   bool result = false;
@@ -168,13 +130,13 @@ bool Box_Data_Calendar_Related::fill_from_database()
     Gnome::Gda::Value date_end_value(date_end);
 
     //Add a WHERE clause for this date range:
-    auto relationship = m_portal->get_relationship();
+    auto relationship = portal->get_relationship();
     Glib::ustring where_clause_to_table_name = relationship->get_to_table();
 
-    auto derived_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(m_portal);
+    auto derived_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(portal);
     const auto date_field_name = derived_portal->get_date_field()->get_name();
 
-    auto relationship_related = m_portal->get_related_relationship();
+    auto relationship_related = portal->get_related_relationship();
     if(relationship_related)
     {
       //Adjust the WHERE clause appropriately for the extra JOIN:
@@ -202,7 +164,7 @@ bool Box_Data_Calendar_Related::fill_from_database()
     }
     else
     {
-      where_clause = Utils::build_combined_where_expression(
+      where_clause = SqlUtils::build_combined_where_expression(
         m_found_set.m_where_clause, extra_where_clause,
         Gnome::Gda::SQL_OPERATOR_TYPE_AND);
     }
@@ -210,7 +172,7 @@ bool Box_Data_Calendar_Related::fill_from_database()
     //Do one SQL query for the whole month and store the cached values here:
     clear_cached_database_values();
 
-    auto sql_query = Utils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_FieldsShown, where_clause, m_found_set.m_extra_join, m_found_set.m_sort_clause);
+    auto sql_query = SqlUtils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_FieldsShown, where_clause, m_found_set.m_extra_join, m_found_set.m_sort_clause);
     //std::cout << "DEBUG: sql_query=" << sql_query << std::endl;
     auto datamodel = DbUtils::query_execute_select(sql_query);
     if(!(datamodel))
@@ -250,7 +212,7 @@ void Box_Data_Calendar_Related::clear_cached_database_values()
 {
   for(const auto& the_pair : m_map_values)
   {
-    type_list_vectors vec = the_pair.second;
+    const auto& vec = the_pair.second;
     for(const auto& pValues : vec)
     {
       delete pValues;
@@ -295,11 +257,13 @@ void Box_Data_Calendar_Related::on_record_added(const Gnome::Gda::Value& primary
   {
     std::shared_ptr<Field> field_primary_key; //TODO: = m_calendar.get_key_field();
 
+    const auto portal = get_portal();
+
     //Create the link by setting the foreign key
-    if(m_key_field && m_portal)
+    if(m_key_field && portal)
     {
       auto builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_UPDATE);
-      const auto target_table = m_portal->get_table_used(Glib::ustring() /* not relevant */);
+      const auto target_table = portal->get_table_used(Glib::ustring() /* not relevant */);
       builder->set_table(target_table);
       builder->add_field_value_as_value(m_key_field->get_name(), m_key_value);
       builder->set_where(
@@ -324,9 +288,10 @@ void Box_Data_Calendar_Related::on_record_added(const Gnome::Gda::Value& primary
 
 Box_Data_Calendar_Related::type_vecConstLayoutFields Box_Data_Calendar_Related::get_fields_to_show() const
 {
-  type_vecConstLayoutFields layout_fields = Box_Data_Portal::get_fields_to_show();
+  auto layout_fields = Box_Data_Portal::get_fields_to_show();
 
-  auto derived_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(m_portal);
+  const auto portal = get_portal();
+  const auto derived_portal = std::dynamic_pointer_cast<const LayoutItem_CalendarPortal>(portal);
   if(!derived_portal)
   {
     std::cerr << G_STRFUNC << ": The portal is not a LayoutItem_CalendarPortal.\n";
@@ -351,13 +316,13 @@ Box_Data_Calendar_Related::type_vecConstLayoutFields Box_Data_Calendar_Related::
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void Box_Data_Calendar_Related::on_dialog_layout_hide()
 {
-  auto dialog_related = dynamic_cast<Dialog_Layout_Calendar_Related*>(m_pDialogLayout);
+  auto dialog_related = dynamic_cast<Dialog_Layout_Calendar_Related*>(m_dialog_layout);
   g_assert(dialog_related);
-  m_portal = dialog_related->get_portal_layout();
-
+  const auto portal = dialog_related->get_portal_layout();
+  set_layout_item(portal, "" /* TODO */);
 
   //Update the UI:
-  auto derived_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(m_portal);
+  auto derived_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(portal);
   init_db_details(derived_portal);
 
   Box_Data::on_dialog_layout_hide();
@@ -386,14 +351,15 @@ void Box_Data_Calendar_Related::prepare_layout_dialog(Dialog_Layout* dialog)
   auto related_dialog = dynamic_cast<Dialog_Layout_Calendar_Related*>(dialog);
   g_assert(related_dialog);
 
-  auto derived_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(m_portal);
+  const auto portal = get_portal();
+  const auto derived_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(portal);
   if(derived_portal && derived_portal->get_has_relationship_name())
   {
     related_dialog->init_with_portal(m_layout_name, m_layout_platform, get_document(), derived_portal);
   }
   else
   {
-    related_dialog->init_with_tablename(m_layout_name, m_layout_platform, get_document(), m_parent_table);
+    related_dialog->init_with_tablename(m_layout_name, m_layout_platform, get_document(), get_parent_table());
   }
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
@@ -406,7 +372,8 @@ void Box_Data_Calendar_Related::on_calendar_month_changed()
 
 Glib::ustring Box_Data_Calendar_Related::on_calendar_details(guint year, guint month, guint day)
 {
-  auto derived_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(m_portal);
+  const auto portal = get_portal();
+  const auto derived_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(portal);
   if(!derived_portal)
   {
     //std::cout << "debug: " << G_STRFUNC << ": date_field is NULL\n";
@@ -438,7 +405,7 @@ Glib::ustring Box_Data_Calendar_Related::on_calendar_details(guint year, guint m
   Glib::ustring result;
 
   //Look at each row for this date:
-  const type_list_vectors& rows = iter_find->second;
+  const auto& rows = iter_find->second;
   for(const auto& pRow : rows)
   {
     if(!pRow)
@@ -451,7 +418,7 @@ Glib::ustring Box_Data_Calendar_Related::on_calendar_details(guint year, guint m
     //We iterate over the original list of items from the portal,
     //instead of the ones used by the query (m_FieldsShown),
     //because we really don't want to show the extra fields (at the end) to the user:
-    LayoutGroup::type_list_items items = m_portal->get_items();
+    LayoutGroup::type_list_items items = portal->get_items();
     for(const auto& layout_item : items)
     {
       if(!layout_item)
@@ -499,27 +466,27 @@ Glib::ustring Box_Data_Calendar_Related::on_calendar_details(guint year, guint m
 
 void Box_Data_Calendar_Related::setup_menu(Gtk::Widget* /* this */)
 {
-  m_refActionGroup = Gio::SimpleActionGroup::create();
+  m_action_group = Gio::SimpleActionGroup::create();
 
-  m_refContextEdit = m_refActionGroup->add_action("edit",
+  m_context_edit = m_action_group->add_action("edit",
     sigc::mem_fun(*this, &Box_Data_Calendar_Related::on_MenuPopup_activate_Edit) );
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   // Don't add ContextLayout in client only mode because it would never
   // be sensitive anyway
-  m_refContextLayout =  m_refActionGroup->add_action("layout",
+  m_context_layout =  m_action_group->add_action("layout",
     sigc::mem_fun(*this, &Box_Data_Calendar_Related::on_MenuPopup_activate_layout) );
 
   //TODO: This does not work until this widget is in a container in the window:
   auto pApp = get_appwindow();
   if(pApp)
   {
-    pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
+    pApp->add_developer_action(m_context_layout); //So that it can be disabled when not in developer mode.
     pApp->update_userlevel_ui(); //Update our action's sensitivity.
   }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  insert_action_group("context", m_refActionGroup);
+  insert_action_group("context", m_action_group);
 
   //TODO: add_accel_group(m_refUIManager->get_accel_group());
 
@@ -527,12 +494,12 @@ void Box_Data_Calendar_Related::setup_menu(Gtk::Widget* /* this */)
   menu->append(_("_Edit"), "context.edit");
   menu->append(_("_Layout"), "context.layout");
 
-  m_pMenuPopup = std::make_unique<Gtk::Menu>(menu);
-  m_pMenuPopup->attach_to_widget(*this);
+  m_menu_popup = std::make_unique<Gtk::Menu>(menu);
+  m_menu_popup->attach_to_widget(*this);
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   if(pApp)
-    m_refContextLayout->set_enabled(pApp->get_userlevel() == AppState::userlevels::DEVELOPER);
+    m_context_layout->set_enabled(pApp->get_userlevel() == AppState::userlevels::DEVELOPER);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 }
 
@@ -544,7 +511,7 @@ void Box_Data_Calendar_Related::on_calendar_button_press_event(GdkEventButton *b
   auto pApp = get_appwindow();
   if(pApp)
   {
-    pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
+    pApp->add_developer_action(m_context_layout); //So that it can be disabled when not in developer mode.
     pApp->update_userlevel_ui(); //Update our action's sensitivity.
   }
 #endif
@@ -554,7 +521,7 @@ void Box_Data_Calendar_Related::on_calendar_button_press_event(GdkEventButton *b
   if(mods & GDK_BUTTON3_MASK)
   {
     //Give user choices of actions on this item:
-    m_pMenuPopup->popup(button_event->button, button_event->time);
+    m_menu_popup->popup(button_event->button, button_event->time);
     return; //handled.
   }
   else
