@@ -22,10 +22,12 @@
 #include <glom/mode_data/box_data_details.h>
 #include <glom/frame_glom.h> //For show_ok_dialog().
 #include <libglom/algorithms_utils.h>
-#include <libglom/data_structure/field.h>
 #include <libglom/data_structure/relationship.h>
 #include <libglom/data_structure/glomconversions.h>
 #include <libglom/db_utils.h>
+#include <libglom/layout_utils.h>
+#include <libglom/sql_utils.h>
+#include <libglom/utils.h>
 #include <glom/mode_design/layout/dialog_layout_details.h>
 #include <glom/glade_utils.h>
 #include <glom/utils_ui.h>
@@ -34,7 +36,6 @@
 #include <glom/print_layout/print_layout_utils.h>
 #include <glom/appwindow.h>
 #include <gtkmm/viewport.h>
-#include <sstream> //For stringstream
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -50,7 +51,7 @@ Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
   m_Button_Nav_Prev(_("_Back"), true),
   m_Button_Nav_Next(_("_Forward"), true),
   m_Button_Nav_Last(_("_Last"), true),
-  m_bDoNotRefreshRelated(false),
+  m_do_not_refresh_related(false),
   m_ignore_signals(true)
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   , m_design_mode(false)
@@ -71,7 +72,7 @@ Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
   //m_strHint = _("When you change the data in a field the database is updated immediately.\n Click [New] to add a new record.\n Leave automatic ID fields empty - they will be filled for you.");
 
 
-  //m_ScrolledWindow.set_border_width(Utils::to_utype(UiUtils::DefaultSpacings::SMALL));
+  //m_scrolled_window.set_border_width(Utils::to_utype(UiUtils::DefaultSpacings::SMALL));
 
   // Allow vertical scrolling, but never scroll horizontally:
   m_ScrolledWindow.set_policy(Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC);
@@ -172,7 +173,7 @@ void Box_Data_Details::set_found_set_from_primary_key_value()
 
   if(!Conversions::value_is_empty(m_primary_key_value))
   {
-    m_found_set.m_where_clause = Utils::build_simple_where_expression(
+    m_found_set.m_where_clause = SqlUtils::build_simple_where_expression(
        m_table_name, m_field_primary_key, m_primary_key_value);
     //std::cout << "debug: " << G_STRFUNC << ": m_found_set.m_where_clause = " << m_found_set.m_where_clause << std::endl;
   }
@@ -284,7 +285,7 @@ bool Box_Data_Details::fill_from_database()
     bResult = Box_Data::fill_from_database();
 
     m_FieldsShown = get_fields_to_show();
-    type_vecConstLayoutFields fieldsToGet = m_FieldsShown;
+    auto fieldsToGet = m_FieldsShown;
 
     if(!fieldsToGet.empty())
     {
@@ -306,7 +307,7 @@ bool Box_Data_Details::fill_from_database()
         bool index_primary_key_found = false;
         unsigned int index_primary_key = 0; //Arbitrary default.
         //g_warning("primary_key name = %s", m_field_primary_key->get_name().c_str());
-        if(!find_if_layout_item_field_is_same_field_exists(fieldsToGet, layout_item_pk))
+        if(!Utils::find_if_layout_item_field_is_same_field_exists(fieldsToGet, layout_item_pk))
         {
           fieldsToGet.emplace_back(layout_item_pk);
           index_primary_key = fieldsToGet.size() - 1;
@@ -343,7 +344,7 @@ bool Box_Data_Details::fill_from_database()
           std::cerr << G_STRFUNC << ": index_primary_key not found and not added. Something went wrong. fieldsToGet.size()=" << fieldsToGet.size() << std::endl;
         }
 
-        auto query = Utils::build_sql_select_with_key(m_table_name, fieldsToGet, m_field_primary_key, m_primary_key_value);
+        auto query = SqlUtils::build_sql_select_with_key(m_table_name, fieldsToGet, m_field_primary_key, m_primary_key_value);
         Glib::RefPtr<Gnome::Gda::DataModel> result;
 
         if(!primary_key_is_empty)
@@ -549,8 +550,8 @@ void Box_Data_Details::on_related_record_added(Gnome::Gda::Value /* strKeyValue
   //Prevent deletion of Related boxes.
   //One of them emitted this signal, and is probably still being edited.
   //This prevents a crash.
-  bool bDoNotRefreshRelated = m_bDoNotRefreshRelated;
-  m_bDoNotRefreshRelated = true;
+  bool do_not_refresh_related = m_do_not_refresh_related;
+  m_do_not_refresh_related = true;
 
   //std::cout << "debug: " << G_STRFUNC << ": " << strKeyValue << ", " << strFromKeyName << std::endl;
   //Get current FromKey value:
@@ -571,7 +572,7 @@ void Box_Data_Details::on_related_record_added(Gnome::Gda::Value /* strKeyValue
 
 
   //Restore value:
-  m_bDoNotRefreshRelated = bDoNotRefreshRelated;
+  m_do_not_refresh_related = do_not_refresh_related;
 }
 
 Box_Data_Details::type_signal_void Box_Data_Details::signal_nav_first()
