@@ -23,11 +23,9 @@
 #include <glom/glade_utils.h>
 #include <glom/mode_design/layout/dialog_layout_list.h>
 #include <libglom/privs.h>
-#include <libglom/db_utils.h>
+#include <libglom/layout_utils.h>
 #include <libglom/utils.h> //For bold_message()).
-#include <sstream> //For stringstream
 #include <glibmm/main.h>
-#include <glibmm/i18n.h>
 
 namespace Glom
 {
@@ -55,7 +53,7 @@ Box_Data_List::Box_Data_List()
 
 
   //Groups are not very helpful for a list view:
-  //m_pDialogLayout->set_show_groups(false);
+  //m_dialog_layout->set_show_groups(false);
 
   m_AddDel.show();
 }
