@@ -24,6 +24,7 @@
 #include <libglom/data_structure/glomconversions.h>
 #include <libglom/db_utils.h>
 #include <libglom/privs.h>
+#include <libglom/utils.h>
 #include <glom/glade_utils.h>
 #include <glom/frame_glom.h> //For show_ok_dialog()
 #include <glom/utils_ui.h> //For bold_message()).
@@ -59,43 +60,56 @@ Box_Data_List_Related::Box_Data_List_Related()
 
 void Box_Data_List_Related::enable_buttons()
 {
+  const auto portal = get_portal();
   const bool view_details_possible =
     get_has_suitable_record_to_view_details() &&
-    (m_portal->get_navigation_type() != LayoutItem_Portal::navigation_type::NONE);
+    portal &&
+    (portal->get_navigation_type() != LayoutItem_Portal::navigation_type::NONE);
 
   // Don't allow the user to go to a record in a hidden table.
   // Unless we are on Maemo - then we want to allow editing in a separate window only.
   m_AddDel.set_allow_view_details(view_details_possible);
 }
 
-bool Box_Data_List_Related::init_db_details(const std::shared_ptr<const LayoutItem_Portal>& portal, bool show_title)
+bool Box_Data_List_Related::init_db_details(const std::shared_ptr<const LayoutItem_Portal>& portal, bool show_title = true)
 {
-  //This calls the other method overload:
-  return Box_Data_Portal::init_db_details(portal, show_title);
+  //Prevent impossible multiple related records:
+  const bool single_related = (m_key_field && (m_key_field->get_unique_key() || m_key_field->get_primary_key()));
+  m_AddDel.set_allow_only_one_related_record(single_related);
+
+  const auto table_name = portal->get_table_used(Glib::ustring() /* parent table_name, not used. */);
+  const auto table_privs = Privs::get_current_privs(table_name);
+  m_AddDel.set_allow_view(table_privs.m_view);
+
+  //TODO: Use m_found_set?
+  FoundSet found_set;
+  found_set.m_table_name = table_name;
+  m_AddDel.set_found_set(found_set);
+
+  const auto result = Box_Data_Portal::init_db_details(portal, show_title);
+  enable_buttons();
+  return result;
 }
 
-bool Box_Data_List_Related::init_db_details(const Glib::ustring& parent_table, bool show_title)
+bool Box_Data_List_Related::init_db_details_without_portal(const Glib::ustring& parent_table)
 {
-  m_parent_table = parent_table;
+  //Prevent impossible multiple related records:
+  m_AddDel.set_allow_only_one_related_record(false);
+  m_AddDel.set_allow_view(false);
 
-  if(m_portal)
-    LayoutWidgetBase::m_table_name = m_portal->get_table_used(Glib::ustring() /* parent table_name, not used. */);
-  else
-    LayoutWidgetBase::m_table_name = Glib::ustring();
+  //TODO: Use m_found_set?
+  FoundSet found_set;
+  m_AddDel.set_found_set(found_set);
 
-  if(LayoutWidgetBase::m_table_name.empty())
+  enable_buttons();
+
+  return Box_Data_Portal::init_db_details_without_portal(parent_table);
+}
+
+void Box_Data_List_Related::show_title_in_ui(const Glib::ustring& title)
+{
+  if(!title.empty())
   {
-    std::cerr << G_STRFUNC << ": LayoutWidgetBase::m_table_name is null\n";
-  }
-  
-  Base_DB_Table::m_table_name = LayoutWidgetBase::m_table_name;
-
-  if(show_title)
-  {
-    Glib::ustring title;
-    if(m_portal)
-      title = item_get_title(m_portal);
-
     m_Label.set_markup(UiUtils::bold_message(title));
     m_Label.show();
 
@@ -104,7 +118,6 @@ bool Box_Data_List_Related::init_db_details(const Glib::ustring& parent_table, b
 
     m_AddDel.set_margin_start(Utils::to_utype(UiUtils::DefaultSpacings::LARGE));
     m_AddDel.set_margin_top(Utils::to_utype(UiUtils::DefaultSpacings::SMALL));
-
   }
   else
   {
@@ -117,31 +130,6 @@ bool Box_Data_List_Related::init_db_details(const Glib::ustring& parent_table, b
     m_AddDel.set_margin_start(0);
     m_AddDel.set_margin_top(0);
   }
-
-  if(m_portal)
-  {
-    m_key_field = DbUtils::get_fields_for_table_one_field(get_document(),
-      LayoutWidgetBase::m_table_name, m_portal->get_to_field_used());
-  }
-  else
-    m_key_field.reset();
-
-
-  //Prevent impossible multiple related records:
-  const bool single_related = (m_key_field && (m_key_field->get_unique_key() || m_key_field->get_primary_key()));
-  m_AddDel.set_allow_only_one_related_record(single_related);
-
-  enable_buttons();
-
-  //TODO: Use m_found_set?
-  FoundSet found_set;
-  found_set.m_table_name = LayoutWidgetBase::m_table_name;
-
-  const auto table_privs = Privs::get_current_privs(found_set.m_table_name);
-  m_AddDel.set_allow_view(table_privs.m_view);
-
-  m_AddDel.set_found_set(found_set);
-  return Box_Data_ManyRecords::init_db_details(found_set, "" /* layout_platform */); //Calls create_layout() and fill_from_database().
 }
 
 bool Box_Data_List_Related::fill_from_database()
@@ -174,8 +162,9 @@ bool Box_Data_List_Related::fill_from_database()
   }
 
   //Prevent addition of new records if that is what the relationship specifies:
-  if(allow_add && m_portal && m_portal->get_relationship())
-    allow_add = m_portal->get_relationship()->get_auto_create();
+  const auto portal = get_portal();
+  if(allow_add && portal && portal->get_relationship())
+    allow_add = portal->get_relationship()->get_auto_create();
 
   m_AddDel.set_allow_add(allow_add);
 
@@ -208,8 +197,15 @@ void Box_Data_List_Related::on_adddel_user_requested_edit(const Gtk::TreeModel::
 
 void Box_Data_List_Related::on_adddel_record_changed()
 {
+  const auto portal = get_portal();
+  if(!portal)
+  {
+    std::cerr << G_STRFUNC << ": portal is null.\n";
+    return;
+  }
+
   //Let parent respond:
-  signal_portal_record_changed().emit(m_portal->get_relationship_name());
+  signal_portal_record_changed().emit(portal->get_relationship_name());
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -302,7 +298,8 @@ void Box_Data_List_Related::on_adddel_record_added(const Gtk::TreeModel::iterato
     auto field_primary_key = m_AddDel.get_key_field();
 
     //Create the link by setting the foreign key
-    if(m_key_field && m_portal)
+    const auto portal = get_portal();
+    if(m_key_field && portal)
     {
       make_record_related(primary_key_value);
 
@@ -327,20 +324,22 @@ void Box_Data_List_Related::on_adddel_record_added(const Gtk::TreeModel::iterato
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void Box_Data_List_Related::on_dialog_layout_hide()
 {
-  auto dialog_related = dynamic_cast<Dialog_Layout_List_Related*>(m_pDialogLayout);
+  auto dialog_related = dynamic_cast<Dialog_Layout_List_Related*>(m_dialog_layout);
   g_assert(dialog_related);
-  m_portal = dialog_related->get_portal_layout();
+
+  const auto portal = dialog_related->get_portal_layout();
+  set_layout_item(portal, "" /* TODO */);
 
 
   //Update the UI:
-  init_db_details(m_portal);
+  init_db_details(portal);
 
   Box_Data::on_dialog_layout_hide();
 
   auto pLayoutItem = std::dynamic_pointer_cast<LayoutItem_Portal>(get_layout_item());
   if(pLayoutItem)
   {
-    *pLayoutItem = *m_portal;
+    *pLayoutItem = *portal;
     signal_layout_changed().emit(); //TODO: Check whether it has really changed.
   }
 }
@@ -359,7 +358,14 @@ void Box_Data_List_Related::prepare_layout_dialog(Dialog_Layout* dialog)
   auto related_dialog = dynamic_cast<Dialog_Layout_List_Related*>(dialog);
   g_assert(related_dialog);
 
-  related_dialog->init_with_portal(m_layout_name, m_layout_platform, get_document(), m_portal, m_parent_table);
+  const auto portal = get_portal();
+  if(!portal)
+  {
+    std::cerr << G_STRFUNC << ": portal is null.\n";
+    return;
+  }
+
+  related_dialog->init_with_portal(m_layout_name, m_layout_platform, get_document(), portal, get_parent_table());
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
@@ -385,8 +391,9 @@ Document::type_list_layout_groups Box_Data_List_Related::create_layout_get_layou
 
   //Do not use get_data_layout_groups(m_layout_name).
   //instead do this:
-  if(m_portal)
-    result.emplace_back(m_portal);
+  const auto portal = get_portal();
+  if(portal)
+    result.emplace_back(portal);
 
   return result;
 }
@@ -408,12 +415,13 @@ void Box_Data_List_Related::create_layout()
   //m_AddDel.set_columns_count(m_Fields.size());
 
   m_AddDel.set_table_name(Base_DB_Table::m_table_name);
-  
-  if(m_portal)
+
+  const auto portal = get_portal();
+  if(portal)
   {
     gulong rows_count_min = 0;
     gulong rows_count_max = 0;
-    m_portal->get_rows_count(rows_count_min, rows_count_max);
+    portal->get_rows_count(rows_count_min, rows_count_max);
     if(rows_count_min) //0 is a silly value.
       m_AddDel.set_height_rows(rows_count_min, rows_count_max);
   }
