@@ -48,9 +48,10 @@ public:
    */
   virtual bool init_db_details(const std::shared_ptr<const LayoutItem_Portal>& portal, bool show_title = true);
 
+  //TODO: Remove this? It might only be called when portal is unexectedly null.
   /** Use this if no portal is yet defined, so the user can use the context menu to define a portal.
    */
-  virtual bool init_db_details(const Glib::ustring& parent_table, bool show_title = true) = 0;
+  virtual bool init_db_details_without_portal(const Glib::ustring& parent_table);
 
   /** Update a portal if a relevant value in its parent table has changed.
    *
@@ -58,7 +59,8 @@ public:
    */
   bool refresh_data_from_database_with_foreign_key(const Gnome::Gda::Value& foreign_key_value);
 
-  std::shared_ptr<LayoutItem_Portal> get_portal() const;
+  std::shared_ptr<LayoutItem_Portal> get_portal();
+  std::shared_ptr<const LayoutItem_Portal> get_portal() const;
   std::shared_ptr<const Field> get_key_field() const;
 
   sigc::signal<void, Gnome::Gda::Value> signal_record_added;
@@ -91,6 +93,9 @@ public:
    */
   virtual void set_find_mode(bool val = true);
 
+  Glib::ustring get_parent_table() const;
+  void set_parent_table(const Glib::ustring& parent_table);
+
 protected:
   type_vecConstLayoutFields get_fields_to_show() const override;
     
@@ -105,11 +110,12 @@ protected:
   void on_dialog_layout_hide() override;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-protected:
   virtual Document::type_list_layout_groups create_layout_get_layout();
 
   void make_record_related(const Gnome::Gda::Value& related_record_primary_key_value);
 
+  virtual void show_title_in_ui(const Glib::ustring& title) = 0;
+
   /** Get the title of the relationship used by the portal.
    */
   Glib::ustring get_title(const Glib::ustring& locale) const;
@@ -121,14 +127,17 @@ protected:
   Gtk::Frame m_Frame;
   Gtk::Label m_Label;
 
-  std::shared_ptr<LayoutItem_Portal> m_portal;
-  Glib::ustring m_parent_table; //A duplicate of the from_table in m_portal, but only when m_portal is not null.
+private:
+  Glib::ustring m_parent_table; //A duplicate of the from_table in the poral, but only when get_portal() is not null.
   
   // m_key_field and m_key_value are the field and its value in this table that 
   // must match another field in the parent table.
+
+public:
   std::shared_ptr<Field> m_key_field;
   Gnome::Gda::Value m_key_value;
 
+private:
   bool m_find_mode;
     
   type_signal_portal_record_changed m_signal_portal_record_changed;
