@@ -26,8 +26,6 @@
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_buttonscript.h>
 #endif
-#include <glibmm/i18n.h>
-//#include <sstream> //For stringstream
 
 namespace Glom
 {
@@ -89,7 +87,7 @@ bool ButtonGlom::on_button_press_event(GdkEventButton *button_event)
     if(mods & GDK_BUTTON3_MASK)
     {
       //Give user choices of actions on this item:
-      m_pPopupMenuUtils->popup(button_event->button, button_event->time);
+      m_popup_menu_utils->popup(button_event->button, button_event->time);
       return true; //We handled this event.
     }
   }
