@@ -42,14 +42,11 @@ class CheckButton
 {
 public:
   explicit CheckButton(const Glib::ustring& title = Glib::ustring());
-  virtual ~CheckButton();
 
   void set_value(const Gnome::Gda::Value& value) override;
   Gnome::Gda::Value get_value() const override;    
 
 private:
-  void init();
-
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   bool on_button_press_event(GdkEventButton *event) override;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
