@@ -22,6 +22,9 @@
 #include <glom/mode_data/datawidget/treemodel_db_withextratext.h>
 #include <libglom/data_structure/glomconversions.h>
 #include <libglom/privs.h>
+#include <libglom/layout_utils.h>
+#include <libglom/sql_utils.h>
+#include <libglom/utils.h>
 #include <glom/utils_ui.h>
 #include <glom/appwindow.h>
 #include <gtkmm/liststore.h>
@@ -29,10 +32,8 @@
 //#include <sstream> //For stringstream
 
 #include <locale>     // for locale, time_put
-#include <ctime>     // for struct tm
 #include <iostream>   // for cout, endl
 
-
 namespace Glom
 {
 
@@ -51,7 +52,7 @@ ComboChoicesWithTreeModel::~ComboChoicesWithTreeModel()
 
 int ComboChoicesWithTreeModel::get_fixed_model_text_column() const
 {
-  const auto count = m_refModel->get_n_columns();
+  const auto count = m_model->get_n_columns();
   if(count > 0)
     return count -1;
   else
@@ -91,7 +92,7 @@ void ComboChoicesWithTreeModel::create_model_non_db(guint columns_count)
   }
 
   //Create the model:
-  m_refModel = Gtk::ListStore::create(record);
+  m_model = Gtk::ListStore::create(record);
 }
 
 void ComboChoicesWithTreeModel::delete_model()
@@ -108,7 +109,7 @@ void ComboChoicesWithTreeModel::set_choices_with_second(const type_list_values_w
     type_list_values_with_second::const_iterator iter= list_values.begin();
     if(iter != list_values.end())
     {
-      const type_list_values& second = iter->second;
+      const auto& second = iter->second;
       columns_count += second.size();
     }
   }
@@ -128,7 +129,7 @@ void ComboChoicesWithTreeModel::set_choices_with_second(const type_list_values_w
   if(layout_choice_extra)
     extra_fields = layout_choice_extra->get_items_recursive();
 
-  auto list_store = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(m_refModel);
+  auto list_store = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(m_model);
   if(!list_store)
   {
     std::cerr << G_STRFUNC << ": list_store is null.\n";
@@ -146,7 +147,7 @@ void ComboChoicesWithTreeModel::set_choices_with_second(const type_list_values_w
         Conversions::get_text_for_gda_value(layout_choice_first->get_glom_type(), the_pair->first, layout_choice_first->get_formatting_used().m_numeric_format);
       row.set_value(0, text);
 
-      const type_list_values extra_values = the_pair->second;
+      const auto& extra_values = the_pair->second;
       if(layout_choice_extra && !extra_values.empty())
       {
         guint model_index = 1; //0 is for the main field.
@@ -183,7 +184,7 @@ void ComboChoicesWithTreeModel::set_choices_fixed(const Formatting::type_list_va
 {
   create_model_non_db(1); //Use a regular ListStore without a dynamic column?
 
-  auto list_store = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(m_refModel);
+  auto list_store = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(m_model);
   if(!list_store)
   {
     std::cerr << G_STRFUNC << ": list_store is null.\n";
@@ -273,7 +274,7 @@ void ComboChoicesWithTreeModel::set_choices_related(const std::shared_ptr<const
   {
     const auto to_field = document->get_field(to_table, choice_relationship->get_to_field());
 
-    found_set.m_where_clause = Utils::build_simple_where_expression(
+    found_set.m_where_clause = SqlUtils::build_simple_where_expression(
       to_table, to_field, foreign_key_value);
   }
 
@@ -290,8 +291,8 @@ void ComboChoicesWithTreeModel::set_choices_related(const std::shared_ptr<const
   //because Combo(has_entry) needs it.
   //TODO: Avoid getting the actual data if the user does not have view rights.
   const auto table_privs = Privs::get_current_privs(found_set.m_table_name);
-  m_refModel = DbTreeModelWithExtraText::create(found_set, layout_items, table_privs.m_view, false /* find mode */, m_db_layout_items);
-  if(!m_refModel)
+  m_model = DbTreeModelWithExtraText::create(found_set, layout_items, table_privs.m_view, false /* find mode */, m_db_layout_items);
+  if(!m_model)
   {
     std::cerr << G_STRFUNC << ": DbTreeModel::create() returned a null model.\n";
   }
@@ -302,7 +303,7 @@ void ComboChoicesWithTreeModel::set_choices_related(const std::shared_ptr<const
 
 Glib::RefPtr<Gtk::TreeModel> ComboChoicesWithTreeModel::get_choices_model()
 {
-  return m_refModel;
+  return m_model;
 }
 
 void ComboChoicesWithTreeModel::set_cell_for_field_value(Gtk::CellRenderer* cell, const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
