@@ -22,14 +22,8 @@
 #include <libglom/data_structure/glomconversions.h>
 #include <gtkmm/messagedialog.h>
 #include <glom/dialog_invalid_data.h>
-#include <libglom/data_structure/glomconversions.h>
 #include <glom/appwindow.h>
 #include <glom/utils_ui.h>
-#include <glibmm/i18n.h>
-//#include <sstream> //For stringstream
-
-#include <locale>     // for locale, time_put
-#include <ctime>     // for struct tm
 #include <iostream>   // for cout, endl
 
 namespace Glom
@@ -191,10 +185,10 @@ bool Entry::on_button_press_event(GdkEventButton *button_event)
   auto pApp = get_appwindow();
   if(pApp)
   {
-    pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
-    pApp->add_developer_action(m_refContextAddField);
-    pApp->add_developer_action(m_refContextAddRelatedRecords);
-    pApp->add_developer_action(m_refContextAddGroup);
+    pApp->add_developer_action(m_context_layout); //So that it can be disabled when not in developer mode.
+    pApp->add_developer_action(m_context_add_field);
+    pApp->add_developer_action(m_context_add_related_records);
+    pApp->add_developer_action(m_context_add_group);
 
     pApp->update_userlevel_ui(); //Update our action's sensitivity. 
 
@@ -207,7 +201,7 @@ bool Entry::on_button_press_event(GdkEventButton *button_event)
       if(mods & GDK_BUTTON3_MASK)
       {
         //Give user choices of actions on this item:
-        m_pMenuPopup->popup(button_event->button, button_event->time);
+        m_menu_popup->popup(button_event->button, button_event->time);
         return true; //We handled this event.
       }
     }
