@@ -23,9 +23,8 @@
 
 #include <libglom/connectionpool.h>
 #include <libglom/data_structure/glomconversions.h> //For util_build_sql
-#include <libglom/utils.h>
+#include <libglom/sql_utils.h>
 #include <libglom/db_utils.h>
-#include <libgdamm/datamodel.h>
 #include <libgdamm/dataaccesswrapper.h>
 #include <libgdamm/datamodelarray.h>
 
@@ -337,7 +336,7 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
 
   if(m_connection && !m_found_set.m_table_name.empty() && m_get_records)
   {
-    auto sql_query = Utils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_extra_join, m_found_set.m_sort_clause);
+    auto sql_query = SqlUtils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_extra_join, m_found_set.m_sort_clause);
     //std::cout << "debug: " << G_STRFUNC << ":  " << sql_query << std::endl;
 
     m_gda_datamodel = DbUtils::query_execute_select(sql_query, true /* use_cursor */);
@@ -348,7 +347,7 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
       m_data_model_columns_count = m_columns_count;
 
       std::cerr << G_STRFUNC << ": error executing SQL. SQL query: \n";
-      std::cerr << G_STRFUNC << ":   " << Utils::sqlbuilder_get_full_query(sql_query) << std::endl;
+      std::cerr << G_STRFUNC << ":   " << SqlUtils::sqlbuilder_get_full_query(sql_query) << std::endl;
       ConnectionPool::handle_error_cerr_only();
       return false; //No records were found.
     }
@@ -369,7 +368,7 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
 
       //This doesn't work with cursor-based models: const int count = m_gda_datamodel->get_n_rows();
       //because rows count is -1 until we have iterated to the last row.
-      auto sql_query_without_sort = Utils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_extra_join, type_sort_clause());
+      auto sql_query_without_sort = SqlUtils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_extra_join);
       const int count = DbUtils::count_rows_returned_by(sql_query_without_sort);
       if(count < 0)
       {
@@ -383,7 +382,15 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
 
       //std::cout << "  rows count=" << m_data_model_rows_count << std::endl;
 
-      m_data_model_columns_count = m_gda_datamodel->get_n_columns();
+      const auto cols_count =  m_gda_datamodel->get_n_columns();
+      if (cols_count < 0)
+      {
+        m_data_model_columns_count = 0; // -1 means unknown, but treat that like 0.
+      }
+      else
+      {
+        m_data_model_columns_count = cols_count;
+      }
 
       return (m_data_model_rows_count > 0); //false is not really a failure, but the caller needs to know whether the foundset found any records.
     }
@@ -436,14 +443,15 @@ void DbTreeModel::get_value_vfunc(const TreeModel::iterator& iter, int column, G
       //Glib::Value< DbValue > value_specific;
       //value_specific.init( Glib::Value< DbValue >::value_type() ); //TODO: Is there any way to avoid this step?
 
-      type_datamodel_row_index datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
+      const auto datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
       //g_warning("DbTreeModel::get_value_vfunc(): datamodel_row=%d, get_internal_rows_count=%d", datamodel_row, get_internal_rows_count());
-      const unsigned int internal_rows_count = get_internal_rows_count();
-      if( datamodel_row < internal_rows_count) //!= m_rows.end())
+      const guint internal_rows_count = std::max(0, get_internal_rows_count());
+
+      if( datamodel_row < (guint)internal_rows_count) //!= m_rows.end())
       {
          //std::cout << "  debug: DbTreeModel::get_value_vfunc() 1.2\n";
 
-        //const typeRow& dataRow = *datamodel_row;
+        //const auto& dataRow = *datamodel_row;
 
         //g_warning("DbTreeModel::get_value_vfunc 1: column=%d, row=%d", column, datamodel_row);
 
@@ -515,7 +523,7 @@ bool DbTreeModel::iter_next_vfunc(const iterator& iter, iterator& iter_next) con
   if( check_treeiter_validity(iter) )
   {
     //Get the current row:
-    type_datamodel_row_index datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
+    auto datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
     //std::cout << "debug: " << G_STRFUNC << ":" << datamodel_row << std::endl;
 
     //Make the iter_next GtkTreeIter represent the next row:
@@ -623,7 +631,7 @@ bool DbTreeModel::iter_parent_vfunc(const iterator& child, iterator& iter) const
 
 Gtk::TreeModel::Path DbTreeModel::get_path_vfunc(const iterator& iter) const
 {
-  type_datamodel_row_index datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
+  const auto datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
 
   //TODO_Performance:
   //Get the number of non-removed items before this iter, because the path index doesn't care about removed internal stuff.
@@ -654,7 +662,7 @@ bool DbTreeModel::create_iterator(const type_datamodel_row_index& datamodel_row,
 
   iter.set_model_refptr(refModel);
 
-  const guint count_all_rows = get_internal_rows_count();
+  const guint count_all_rows = std::max(0, get_internal_rows_count());
   //g_warning("DbTreeModel::create_iterator(): datamodel_row=%d, count=%d", datamodel_row, count_all_rows);
   if(datamodel_row >= (count_all_rows)) //datamodel_row == m_rows.end()) //1 for the placeholder.
   {
@@ -730,7 +738,7 @@ DbTreeModel::iterator DbTreeModel::append()
   //m_rows.resize(existing_size + 1);
 
   //Get aniterator to the last element:
-  type_datamodel_row_index datamodel_row = get_internal_rows_count();
+  const auto datamodel_row = get_internal_rows_count();
   //std::cerr << G_STRFUNC << ": new row number=" << datamodel_row << std::endl;
   ++m_count_extra_rows; //So that create_iterator() can succeed.
 
@@ -766,7 +774,7 @@ void DbTreeModel::set_value_impl(const iterator& row, int column, const Glib::Va
   if(iter_is_valid(row))
   {
     //Get the index from the user_data:
-    type_datamodel_row_index datamodel_row = get_datamodel_row_index_from_tree_row_iter(row);
+    const auto datamodel_row = get_datamodel_row_index_from_tree_row_iter(row);
 
     //TODO: Check column against get_n_columns() too, though it could hurt performance.
 
@@ -806,7 +814,7 @@ DbTreeModel::iterator DbTreeModel::erase(const iterator& iter)
   if(iter_is_valid(iter))
   {
     //Get the index from the user_data:
-    type_datamodel_row_index datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
+    auto datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
 
     //Remove the row.
     Gtk::TreeModel::Path path_deleted = get_path(iter);
@@ -836,7 +844,7 @@ void DbTreeModel::set_key_value(const TreeModel::iterator& iter, const DbValue&
   //g_warning("DbTreeModel::set_is_placeholder(): val=%d", val);
   if(check_treeiter_validity(iter))
   {
-    type_datamodel_row_index datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
+    const auto datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
     m_map_rows[datamodel_row].m_key = value;
   }
 }
@@ -845,7 +853,7 @@ DbTreeModel::DbValue DbTreeModel::get_key_value(const TreeModel::iterator& iter)
 {
   if(check_treeiter_validity(iter))
   {
-    type_datamodel_row_index datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
+    const auto datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
     auto iterFind = m_map_rows.find(datamodel_row);
     if(iterFind != m_map_rows.end())
       return iterFind->second.m_key;
@@ -865,7 +873,7 @@ bool DbTreeModel::get_is_placeholder(const TreeModel::iterator& iter) const
   //g_warning("DbTreeModel::g et_is_placeholder()");
   if(check_treeiter_validity(iter))
   {
-    type_datamodel_row_index datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
+    const auto datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
     return (datamodel_row == ((type_datamodel_row_index)get_internal_rows_count() -1));
   }
 
@@ -905,7 +913,7 @@ Gtk::TreeModel::iterator DbTreeModel::get_last_row()
   const int rows_count = get_internal_rows_count();
   if(rows_count)
   {
-    type_datamodel_row_index row = rows_count - 1;
+    auto row = rows_count - 1;
     
     if(row > 0) //This should always be true, because there is always a placeholder.
       --row; //Ignore the placeholder.
@@ -934,7 +942,7 @@ Gtk::TreeModel::iterator DbTreeModel::get_placeholder_row()
   const int rows_count = get_internal_rows_count();
   if(rows_count)
   {
-    type_datamodel_row_index row = rows_count - 1;
+    auto row = rows_count - 1;
 
     //Step backwards until we find one that is not removed:
     while((m_map_rows.find(row) != m_map_rows.end()) && m_map_rows[row].m_removed)
