@@ -55,7 +55,7 @@ public:
   DbAddDel();
   virtual ~DbAddDel();
 
-  virtual void set_allow_user_actions(bool bVal = true);
+  virtual void set_allow_user_actions(bool value = true);
   bool get_allow_user_actions() const;
 
   virtual void set_allow_add(bool val = true);
@@ -188,7 +188,7 @@ public:
 
   void finish_editing(); //Closes active edit controls and commits the data to the cell.
   //void reactivate(); //Sheet doesn't seem to update unless a cell is active.
-  void set_prevent_user_signals(bool bVal = true);
+  void set_prevent_user_signals(bool value = true);
 
   //TODO_refactor: make private.
 
@@ -378,15 +378,13 @@ private:
 
   void refresh_cell_choices_data_from_database_with_foreign_key(guint model_index, const Gnome::Gda::Value& foreign_key_value);
 
-  static void apply_formatting(Gtk::CellRenderer* renderer, const std::shared_ptr<const LayoutItem_WithFormatting>& layout_item);
-
   typedef Gtk::Box type_base;
 
   //Member widgets:
-  Gtk::ScrolledWindow m_ScrolledWindow;
-  Gtk::TreeView m_TreeView;
+  Gtk::ScrolledWindow m_scrolled_window;
+  Gtk::TreeView m_tree_view;
 
-  Glib::RefPtr<DbTreeModel> m_refListStore;
+  Glib::RefPtr<DbTreeModel> m_list_store;
 
   //Columns, not including the hidden internal columns:
   typedef LayoutGroup::type_list_items type_column_items;
@@ -402,20 +400,20 @@ protected:
 
 private:
   //TODO: Avoid repeating these in so many widgets:
-  std::unique_ptr<Gtk::Menu> m_pMenuPopup;
-  Glib::RefPtr<Gio::SimpleActionGroup> m_refActionGroup;
-  Glib::RefPtr<Gio::SimpleAction> m_refContextEdit, m_refContextAdd, m_refContextDelete;
+  std::unique_ptr<Gtk::Menu> m_menu_popup;
+  Glib::RefPtr<Gio::SimpleActionGroup> m_action_group;
+  Glib::RefPtr<Gio::SimpleAction> m_context_edit, m_context_add, m_context_delete;
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  Glib::RefPtr<Gio::SimpleAction> m_refContextLayout;
+  Glib::RefPtr<Gio::SimpleAction> m_context_layout;
 #endif
 
-  bool m_bAllowUserActions;
+  bool m_allow_user_actions;
 
-  bool m_bPreventUserSignals;
-  bool m_bIgnoreTreeViewSignals;
+  bool m_prevent_user_signals;
+  bool m_ignore_tree_view_signals;
 
-  type_vec_strings m_vecColumnIDs; //We give each ViewColumn a special ID, so we know where they are after a reorder.
+  type_vec_strings m_column_ids; //We give each ViewColumn a special ID, so we know where they are after a reorder.
 
 protected:
   bool m_allow_add;
