@@ -30,6 +30,7 @@
 #include <glom/appwindow.h>
 #include <gtkmm/checkbutton.h>
 #include <libglom/data_structure/glomconversions.h>
+#include <libglom/utils.h>
 #include <glom/glade_utils.h>
 #include <glom/mode_data/box_data_list_related.h>
 #include <glom/mode_design/layout/dialog_choose_relationship.h>
@@ -267,7 +268,7 @@ Box_Data_List_Related* FlowTableWithFields::create_related(const std::shared_ptr
     if(portal && portal->get_has_relationship_name())
       portal_box->init_db_details(portal, show_title);
     else
-      portal_box->init_db_details(m_table_name, show_title);
+      portal_box->init_db_details_without_portal(m_table_name);
 
     Glib::ustring to_table;
     auto relationship = document->get_relationship(m_table_name, portal->get_relationship_name());
@@ -307,7 +308,7 @@ Box_Data_Calendar_Related* FlowTableWithFields::create_related_calendar(const st
     if(portal && portal->get_has_relationship_name())
       portal_box->init_db_details(portal, show_title);
     else
-      portal_box->init_db_details(m_table_name, show_title);
+      portal_box->init_db_details_without_portal(m_table_name);
 
     Glib::ustring to_table;
     auto relationship = document->get_relationship(m_table_name, portal->get_relationship_name());
@@ -716,7 +717,7 @@ void FlowTableWithFields::set_other_field_value(const std::shared_ptr<const Layo
 
 Gnome::Gda::Value FlowTableWithFields::get_field_value(const std::shared_ptr<const LayoutItem_Field>& field) const
 {
-  const type_list_const_widgets list_widgets = get_field(field, true);
+  const auto list_widgets = get_field(field, true);
   for(const auto& list_widget : list_widgets)
   {
     const auto datawidget = dynamic_cast<const DataWidget*>(list_widget);
@@ -802,7 +803,7 @@ FlowTableWithFields::type_portals FlowTableWithFields::get_portals(const std::sh
   {
     if(subtable)
     {
-      type_portals sub_list = subtable->get_portals(from_key);
+      const auto sub_list = subtable->get_portals(from_key);
       if(!sub_list.empty())
       {
         //Add to the main result:
@@ -926,7 +927,7 @@ FlowTableWithFields::type_list_widgets FlowTableWithFields::get_field(const std:
   {
     if(subtable)
     {
-      type_list_widgets sub_list = subtable->get_field(layout_item, include_item);
+      const auto sub_list = subtable->get_field(layout_item, include_item);
       if(!sub_list.empty())
       {
         //Add to the main result:
@@ -1312,7 +1313,7 @@ bool FlowTableWithFields::on_button_press_event(GdkEventButton *button_event)
     if(mods & GDK_BUTTON3_MASK)
     {
       //Give user choices of actions on this item:
-      m_pPopupMenuUtils->popup(button_event->button, button_event->time);
+      m_popup_menu_utils->popup(button_event->button, button_event->time);
       return true; //We handled this event.
     }
   }
