@@ -42,10 +42,6 @@ Dialog_Design::Dialog_Design(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Bu
   show_all_children();
 }
 
-Dialog_Design::~Dialog_Design()
-{
-}
-
 bool Dialog_Design::init_db_details(const Glib::ustring& table_name)
 {
   if(get_document())
@@ -53,7 +49,7 @@ bool Dialog_Design::init_db_details(const Glib::ustring& table_name)
     Glib::ustring table_label = _("None selected");
 
     //Show the table title (if any) and name:
-     auto document = dynamic_cast<Document*>(get_document());
+     auto document = std::dynamic_pointer_cast<Document>(get_document());
      if(document)
      {
        Glib::ustring table_title = document->get_table_title(table_name, AppWindow::get_current_locale());
