@@ -48,11 +48,6 @@ ComboBox_Fields::ComboBox_Fields(BaseObjectType* cobject, const Glib::RefPtr<Gtk
   set_row_separator_func(sigc::mem_fun(*this, &ComboBox_Fields::on_row_separator));
 }
 
-ComboBox_Fields::~ComboBox_Fields()
-{
-
-}
-
 std::shared_ptr<Field> ComboBox_Fields::get_selected_field() const
 {
   auto iter = get_active();
@@ -67,7 +62,7 @@ std::shared_ptr<Field> ComboBox_Fields::get_selected_field() const
 
 Glib::ustring ComboBox_Fields::get_selected_field_name() const
 {
-  std::shared_ptr<Field> field = get_selected_field();
+  auto field = get_selected_field();
   return glom_get_sharedptr_name(field);
 }
 
@@ -82,7 +77,7 @@ void ComboBox_Fields::set_selected_field(const std::shared_ptr<const Field>& fie
 void ComboBox_Fields::set_selected_field(const Glib::ustring& field_name)
 {
   //Look for the row with this text, and activate it:
-  Glib::RefPtr<Gtk::TreeModel> model = get_model();
+  auto model = get_model();
   if(model)
   {
     for(const auto& row : model->children())
@@ -107,7 +102,7 @@ void ComboBox_Fields::set_selected_field(const Glib::ustring& field_name)
     unset_active();
 }
 
-void ComboBox_Fields::set_fields(Document* document, const Glib::ustring parent_table_name)
+void ComboBox_Fields::set_fields(const std::shared_ptr<Document>& document, const Glib::ustring parent_table_name)
 {
   if(!document)
     return;
@@ -123,13 +118,13 @@ void ComboBox_Fields::set_fields(Document* document, const Glib::ustring parent_
     auto tree_iter = m_model->append();
     Gtk::TreeModel::Row row = *tree_iter;
 
-    std::shared_ptr<Field> rel = field;
+    auto rel = field;
     row[m_model_columns.m_field] = rel;
     row[m_model_columns.m_separator] = false;
   }
 }
 
-void ComboBox_Fields::set_fields(Document* document, const Glib::ustring parent_table_name, Field::glom_field_type field_type)
+void ComboBox_Fields::set_fields(const std::shared_ptr<Document>& document, const Glib::ustring parent_table_name, Field::glom_field_type field_type)
 {
   if(!document)
     return;
@@ -144,9 +139,9 @@ void ComboBox_Fields::set_fields(Document* document, const Glib::ustring parent_
   {
     if(rel && (rel->get_glom_type() == field_type))
     {
-      std::cout << "DEBUG: ComboBox_Fields::set_fields() 1" << std::endl;
+      std::cout << "DEBUG: ComboBox_Fields::set_fields() 1\n";
       auto tree_iter = m_model->append();
-      std::cout << "DEBUG: ComboBox_Fields::set_fields() 2" << std::endl;
+      std::cout << "DEBUG: ComboBox_Fields::set_fields() 2\n";
       Gtk::TreeModel::Row row = *tree_iter;
 
       row[m_model_columns.m_field] = rel;
