@@ -53,11 +53,6 @@ ComboBox_Relationship::ComboBox_Relationship(BaseObjectType* cobject, const Glib
   set_row_separator_func(sigc::mem_fun(*this, &ComboBox_Relationship::on_row_separator));
 }
 
-ComboBox_Relationship::~ComboBox_Relationship()
-{
-
-}
-
 std::shared_ptr<Relationship> ComboBox_Relationship::get_selected_relationship() const
 {
   auto iter = get_active();
@@ -109,7 +104,7 @@ void ComboBox_Relationship::set_selected_relationship(const std::shared_ptr<cons
 void ComboBox_Relationship::set_selected_relationship(const Glib::ustring& relationship_name, const Glib::ustring& related_relationship_name)
 {
   //Look for the row with this text, and activate it:
-  Glib::RefPtr<Gtk::TreeModel> model = get_model();
+  auto model = get_model();
   if(model)
   {
     for(const auto& row : model->children())
@@ -150,7 +145,7 @@ void ComboBox_Relationship::set_selected_relationship(const Glib::ustring& relat
     unset_active();
 }
 
-void ComboBox_Relationship::set_relationships(Document* document, const Glib::ustring parent_table_name, bool show_related_relationships, bool show_parent_table_name)
+void ComboBox_Relationship::set_relationships(const std::shared_ptr<Document>& document, const Glib::ustring parent_table_name, bool show_related_relationships, bool show_parent_table_name)
 {
   if(!document)
     return;
