@@ -19,9 +19,7 @@
  */
 
 #include <glom/mode_design/layout/dialog_layout_calendar_related.h>
-#include <glom/mode_design/layout/dialog_choose_field.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_field_layout.h>
-#include <libglom/utils.h> //For bold_message()).
 
 //#include <libgnome/gnome-i18n.h>
 #include <gtkmm/togglebutton.h>
