@@ -25,6 +25,8 @@
 #include <glom/frame_glom.h> //For show_ok_dialog()
 //#include <libgnome/gnome-i18n.h>
 #include <glom/utils_ui.h> //For bold_message()).
+#include <libglom/utils.h>
+#include <libglom/string_utils.h>
 #include <glom/appwindow.h>
 #include <glibmm/i18n.h>
 #include <sstream> //For stringstream
@@ -519,7 +521,7 @@ void Dialog_Layout_Details::on_button_down()
 
 void Dialog_Layout_Details::on_button_add_field()
 {
-  type_list_field_items fields_list = offer_field_list(m_table_name, this);
+  const auto fields_list = offer_field_list(m_table_name, this);
   for(const auto& layout_item : fields_list)
   {
     if(!layout_item)
