@@ -20,7 +20,6 @@
 
 
 #include "dialog_line.h"
-#include <libglom/data_structure/glomconversions.h>
 #include <iostream>
 
 //#include <libgnome/gnome-i18n.h>
@@ -52,6 +51,7 @@ void Dialog_Line::set_line(const std::shared_ptr<const LayoutItem_Line>& line)
   if(!line)
   {
     std::cerr << G_STRFUNC << ": line is null\n";
+    return;
   }
 
   //set_blocked();
