@@ -63,7 +63,7 @@ Dialog_SortFields::Dialog_SortFields(BaseObjectType* cobject, const Glib::RefPtr
 
 
     //Respond to changes of selection:
-    Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_fields->get_selection();
+    auto refSelection = m_treeview_fields->get_selection();
     if(refSelection)
     {
       refSelection->signal_changed().connect( sigc::mem_fun(*this, &Dialog_SortFields::on_treeview_fields_selection_changed) );
@@ -91,10 +91,6 @@ Dialog_SortFields::Dialog_SortFields(BaseObjectType* cobject, const Glib::RefPtr
   show_all_children();
 }
 
-Dialog_SortFields::~Dialog_SortFields()
-{
-}
-
 void Dialog_SortFields::set_fields(const Glib::ustring& table_name, const LayoutItem_GroupBy::type_list_sort_fields& fields)
 {
   m_modified = false;
@@ -114,7 +110,7 @@ void Dialog_SortFields::set_fields(const Glib::ustring& table_name, const Layout
     guint field_sequence = 0;
     for(const auto& the_pair : fields)
     {
-      std::shared_ptr<const LayoutItem_Field> item = std::dynamic_pointer_cast<const LayoutItem_Field>(the_pair.first);
+      auto item = std::dynamic_pointer_cast<const LayoutItem_Field>(the_pair.first);
 
       auto iterTree = m_model_fields->append();
       Gtk::TreeModel::Row row = *iterTree;
@@ -134,7 +130,7 @@ void Dialog_SortFields::set_fields(const Glib::ustring& table_name, const Layout
 void Dialog_SortFields::enable_buttons()
 {
   //Fields:
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_fields->get_selection();
+  auto refSelection = m_treeview_fields->get_selection();
   if(refSelection)
   {
     auto iter = refSelection->get_selected();
@@ -194,10 +190,10 @@ LayoutItem_GroupBy::type_list_sort_fields Dialog_SortFields::get_fields() const
     const auto field_name = item->get_name();
     if(!field_name.empty())
     {
-      std::shared_ptr<LayoutItem_Field> field_copy = glom_sharedptr_clone(item);
+      auto field_copy = glom_sharedptr_clone(item);
 
       const bool ascending = row[m_ColumnsFields.m_col_ascending];
-      result.push_back( LayoutItem_GroupBy::type_pair_sort_field(field_copy, ascending) );
+      result.emplace_back( LayoutItem_GroupBy::type_pair_sort_field(field_copy, ascending) );
 
       ++field_sequence;
     }
@@ -230,7 +226,7 @@ void Dialog_SortFields::on_button_add_field()
       row[m_ColumnsFields.m_col_ascending] = true; //Default to this so that alphabetical searches go from A to Z by default.
 
       //Scroll to, and select, the new row:
-      Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+      auto refTreeSelection = m_treeview_fields->get_selection();
       if(refTreeSelection)
         refTreeSelection->select(iter);
 
@@ -243,7 +239,7 @@ void Dialog_SortFields::on_button_add_field()
 
 void Dialog_SortFields::on_button_delete()
 {
-  Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+  auto refTreeSelection = m_treeview_fields->get_selection();
   if(refTreeSelection)
   {
     //TODO: Handle multiple-selection:
@@ -278,7 +274,7 @@ void Dialog_SortFields::on_cell_data_name(Gtk::CellRenderer* renderer, const Gtk
 
 void Dialog_SortFields::on_button_edit_field()
 {
-  Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+  auto refTreeSelection = m_treeview_fields->get_selection();
   if(refTreeSelection)
   {
     //TODO: Handle multiple-selection:
@@ -289,7 +285,7 @@ void Dialog_SortFields::on_button_edit_field()
       std::shared_ptr<const LayoutItem_Field> field = row[m_ColumnsFields.m_col_layout_item];
 
       //Get the chosen field:
-      std::shared_ptr<LayoutItem_Field> field_chosen = 
+      auto field_chosen = 
         offer_field_list_select_one_field(field, m_table_name, this);
       if(field_chosen)
 
@@ -299,7 +295,7 @@ void Dialog_SortFields::on_button_edit_field()
 
       //Scroll to, and select, the new row:
       /*
-      Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+      auto refTreeSelection = m_treeview_fields->get_selection();
       if(refTreeSelection)
         refTreeSelection->select(iter);
 
