@@ -33,9 +33,11 @@
 #include <glom/appwindow.h>
 #include <libglom/data_structure/glomconversions.h>
 #include <libglom/db_utils.h>
+#include <libglom/layout_utils.h>
+#include <libglom/sql_utils.h>
+#include <libglom/utils.h>
 
 #include <glom/glade_utils.h>
-#include <gtkmm/builder.h>
 #include <giomm/menu.h>
 #include <glibmm/i18n.h>
 
@@ -742,7 +744,7 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
   type_map_layout_fields_index map_fields_index;
 
   //Get list of fields to get from the database.
-  Utils::type_vecLayoutFields fieldsToGet;
+  SqlUtils::type_vecLayoutFields fieldsToGet;
   const int count = canvas_group->get_n_children();
   guint field_i = 0;
   for(int i = 0; i < count; ++i)
@@ -788,7 +790,7 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
   if(fieldsToGet.empty())
     return;
 
-  const Glib::RefPtr<const Gnome::Gda::SqlBuilder> sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name,
+  const Glib::RefPtr<const Gnome::Gda::SqlBuilder> sql_query = SqlUtils::build_sql_select_with_where_clause(found_set.m_table_name,
     fieldsToGet,
     found_set.m_where_clause, std::shared_ptr<const Relationship>() /* extra_join */, found_set.m_sort_clause,
     1);
@@ -810,7 +812,7 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
 
   if(datamodel)
   {
-    const guint rows_count = datamodel->get_n_rows();
+    const auto rows_count = datamodel->get_n_rows(); // -1 means unknown.
     if(rows_count > 0)
       records_found = true;
   }
@@ -898,28 +900,29 @@ void Canvas_PrintLayout::fill_with_data_portal(const Glib::RefPtr<CanvasLayoutIt
   const LayoutGroup::type_list_items child_layout_items = portal->get_items();
 
   //Build and run the SQL query for this portal:
-  const type_vecConstLayoutFields fields_shown = get_portal_fields_to_show(portal);
+  const auto fields_shown = get_portal_fields_to_show(portal);
 
   FoundSet found_set;
   found_set.m_table_name = portal->get_table_used(Glib::ustring() /* parent table_name, not used. */);
   set_found_set_where_clause_for_portal(found_set, portal, foreign_key_value);
 
-  const Glib::RefPtr<Gnome::Gda::SqlBuilder> sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name, fields_shown, found_set.m_where_clause, found_set.m_extra_join, found_set.m_sort_clause);
+  const Glib::RefPtr<Gnome::Gda::SqlBuilder> sql_query = SqlUtils::build_sql_select_with_where_clause(found_set.m_table_name, fields_shown, found_set.m_where_clause, found_set.m_extra_join, found_set.m_sort_clause);
   //std::cout << "DEBUG: sql_query=" << sql_query << std::endl;
   const auto datamodel = DbUtils::query_execute_select(sql_query);
   if(!(datamodel))
     return;
 
-  const int db_rows_count = datamodel->get_n_rows(); //TODO: Performance? COUNT them instead?
-  const int db_columns_count = datamodel->get_n_columns();
+  // -1 means unknown, but we treat that like 0.
+  const guint db_rows_count = std::max(0, datamodel->get_n_rows()); //TODO: Performance? COUNT them instead?
+  const guint db_columns_count = std::max(0, datamodel->get_n_columns());
 
   //Show as many rows as needed, but not more than the maximum:
   gulong rows_count_min = 0;
   gulong rows_count_max = 0;
   portal->get_rows_count(rows_count_min, rows_count_max);
-  int rows_count = std::min((int)rows_count_max, db_rows_count);
+  auto rows_count = std::min(rows_count_max, (gulong)db_rows_count);
   //Do not use less than the minimum:
-  rows_count = std::max(rows_count, (int)rows_count_min);
+  rows_count = std::max(rows_count, rows_count_min);
 
   const double portal_height = rows_count * portal->get_print_layout_row_height();
 
@@ -938,14 +941,14 @@ void Canvas_PrintLayout::fill_with_data_portal(const Glib::RefPtr<CanvasLayoutIt
   canvas_item->add_portal_rows_if_necessary(rows_count);
   //TODO: Move everything else down.
 
-  const int cols_count = child_layout_items.size();
+  const auto cols_count = child_layout_items.size();
 
   //Set the DB value for each cell:
-  for(int row = 0; row < rows_count; ++row)
+  for(guint row = 0; row < rows_count; ++row)
   {
-    int db_col = 0;
+    guint db_col = 0;
     auto iter_child_layout_items = child_layout_items.begin();
-    for(int col = 0; col < cols_count; ++col)
+    for(guint col = 0; col < cols_count; ++col)
     {
       //Glib::RefPtr<Goocanvas::Item> canvas_child = base_item->get_cell_child(row, col); //TODO: Add this to Goocanvas::Table.
       auto canvas_child = 
@@ -1053,7 +1056,7 @@ void Canvas_PrintLayout::set_grid_gap(double gap)
     m_bounds_group->lower();
 }
 
-Base_DB::type_vecConstLayoutFields Canvas_PrintLayout::get_portal_fields_to_show(const std::shared_ptr<LayoutItem_Portal>& portal)
+Base_DB::type_vecConstLayoutFields Canvas_PrintLayout::get_portal_fields_to_show(const std::shared_ptr<const LayoutItem_Portal>& portal)
 {
   const auto document = get_document();
   if(!document)
@@ -1061,7 +1064,7 @@ Base_DB::type_vecConstLayoutFields Canvas_PrintLayout::get_portal_fields_to_show
 
   if(document && portal)
   {
-    Document::type_list_layout_groups mapGroups;
+    Document::type_list_const_layout_groups mapGroups;
     mapGroups.emplace_back(portal);
 
     auto relationship = portal->get_relationship();
