@@ -33,9 +33,6 @@
 #include <libglom/data_structure/glomconversions.h>
 #include <list>
 #include <glib.h> //For g_warning().
-#include <glibmm/i18n.h>
-
-#include <gtkmm/messagedialog.h>
 
 #include <iostream>
 
@@ -54,7 +51,7 @@ static std::list<Glib::ustring> ustring_tokenize(const Glib::ustring& msg, const
 
   while(str.find(separators) != Glib::ustring::npos && (nocount? true : count!=maxParts))
   {
-    unsigned int pos = str.find(separators);
+    auto pos = str.find(separators);
     Glib::ustring tmp = str.substr(0, pos);
     str = str.erase(0, pos + separators.size());
     result.emplace_back(tmp);
