@@ -81,7 +81,7 @@ public:
   // Set the accessible name for the TreeView widget
   void set_treeview_accessible_name(const Glib::ustring& name);
 
-  virtual void set_allow_user_actions(bool bVal = true);
+  virtual void set_allow_user_actions(bool value = true);
   bool get_allow_user_actions() const;
 
   virtual void set_allow_add(bool val = true);
@@ -126,7 +126,7 @@ public:
   //void set_value(const Gtk::TreeModel::iterator& iter, guint col, const Gnome::Gda::Value& value);
   void set_value(const Gtk::TreeModel::iterator& iter, guint col, const Glib::ustring& strValue);
   void set_value(const Gtk::TreeModel::iterator& iter, guint col, unsigned long ulValue);
-  void set_value(const Gtk::TreeModel::iterator& iter, guint col, bool bVal);
+  void set_value(const Gtk::TreeModel::iterator& iter, guint col, bool value);
 
   //void set_value_selected(guint col, const Gnome::Gda::Value& value);
 
@@ -167,7 +167,7 @@ public:
 
   void finish_editing(); //Closes active edit controls and commits the data to the cell.
   //void reactivate(); //Sheet doesn't seem to update unless a cell is active.
-  void set_prevent_user_signals(bool bVal = true);
+  void set_prevent_user_signals(bool value = true);
 
   /** When this is set to true, a new row will be added automatically, and the cursor will be placed in the first column of the new row.
    * Use set_auto_add(false) if you want to provide default values for columns in the new row, or if you want to place the cursor in a different column.
@@ -257,18 +257,13 @@ private:
 
   void on_treeview_button_press_event(GdkEventButton* button_event);
 
-  /** Set the menu to popup when the user right-clicks on the column titles.
-   * This method does not take ownership of the Gtk::Menu.
-   */
-  void set_column_header_popup(Gtk::Menu& popup);
-
   bool row_has_duplicates(const Gtk::TreeModel::iterator& iter) const;
   void warn_about_duplicate();
 
   bool get_prevent_user_signals() const;
 
   //Sometimes the sheet sends signals when it shouldn't:
-  void set_ignore_treeview_signals(bool bVal = true);
+  void set_ignore_treeview_signals(bool value = true);
   bool get_ignore_treeview_signals() const;
 
   bool get_view_column_index(guint model_column_index, guint& view_column_index);
@@ -282,31 +277,31 @@ private:
   typedef Gtk::Box type_base;
 
   //Member widgets:
-  Gtk::ScrolledWindow m_ScrolledWindow;
+  Gtk::ScrolledWindow m_scrolled_window;
 
 protected:
-  Gtk::TreeView m_TreeView;
+  Gtk::TreeView m_tree_view;
 
 private:
-  Gtk::TreeModel::ColumnRecord m_ColumnRecord;
-  Glib::RefPtr<Gtk::ListStore> m_refListStore;
+  Gtk::TreeModel::ColumnRecord m_column_record;
+  Glib::RefPtr<Gtk::ListStore> m_list_store;
   guint m_col_key; //The index of the hidden model column.
   guint m_col_placeholder; //The index of the placeholder-marker model column.
 
   typedef std::vector<AddDelColumnInfo> type_ColumnTypes;
-  type_ColumnTypes m_ColumnTypes;
+  type_ColumnTypes m_column_types;
 
-  bool m_bAllowUserActions;
+  bool m_allow_user_actions;
 
-  bool m_bPreventUserSignals;
-  bool m_bIgnoreSheetSignals;
+  bool m_prevent_user_signals;
+  bool m_ignore_sheet_signals;
 
-  type_vec_strings m_vecColumnIDs; //We give each ViewColumn a special ID, so we know where they are after a reorder.
+  type_vec_strings m_column_ids; //We give each ViewColumn a special ID, so we know where they are after a reorder.
 
-  Glib::ustring m_strTextActiveCell; //value before the change
-  std::unique_ptr<Gtk::Menu> m_pMenuPopup;
-  Glib::RefPtr<Gio::SimpleActionGroup> m_refActionGroup;
-  Glib::RefPtr<Gio::SimpleAction> m_refContextEdit, m_refContextDelete;
+  Glib::ustring m_text_active_cell; //value before the change
+  std::unique_ptr<Gtk::Menu> m_menu_popup;
+  Glib::RefPtr<Gio::SimpleActionGroup> m_action_Group;
+  Glib::RefPtr<Gio::SimpleAction> m_context_edit, m_context_delete;
 
 protected:
   bool m_auto_add;
@@ -334,7 +329,7 @@ private:
     ~InnerIgnore();
 
   protected:
-    AddDel* m_pOuter;
+    AddDel* m_outer;
     bool m_bPreventUserSignals, m_bIgnoreSheetSignals;
   };
 
