@@ -46,7 +46,7 @@ DialogImageLoadProgress::DialogImageLoadProgress(BaseObjectType* cobject, const
 
   if(!m_progress_bar)
   {
-    std::cerr << G_STRFUNC << ": Missing widgets from glade file for DialogImageLoadProgress" << std::endl;
+    std::cerr << G_STRFUNC << ": Missing widgets from glade file for DialogImageLoadProgress\n";
   }
 }
 
@@ -63,7 +63,7 @@ void DialogImageLoadProgress::load(const Glib::ustring& uri)
   // Can only load one file with data 
   g_assert(!m_data.get());
 
-  m_data = std::make_shared<GdaBinary>();
+  m_data = std::make_unique<GdaBinary>();
   m_data->data = nullptr;
   m_data->binary_length = 0;
 
@@ -99,7 +99,7 @@ void DialogImageLoadProgress::on_query_info(const Glib::RefPtr<Gio::AsyncResult>
 {
   try
   {
-    Glib::RefPtr<Gio::FileInfo> info = m_stream->query_info_finish(result);
+    auto info = m_stream->query_info_finish(result);
     m_data->binary_length = info->get_size();
 
     // We need to use the glib allocator here:
@@ -165,11 +165,11 @@ void DialogImageLoadProgress::error(const Glib::ustring& error_message)
   response(Gtk::RESPONSE_REJECT);
 }
 
-std::shared_ptr<GdaBinary> DialogImageLoadProgress::get_image_data()
+std::unique_ptr<GdaBinary> DialogImageLoadProgress::get_image_data()
 {
-  auto result = m_data;
-  m_data.reset();
-  return result;
+  //This will not be as if it was reset.
+  //Not every std::move() does that, but std::move() with std::unique_ptr<> does.
+  return std::move(m_data);
 }
 
 } // namespace Glom
