@@ -27,9 +27,10 @@
 #include <libglom/data_structure/glomconversions.h>
 #include <glom/utility_widgets/dialog_image_load_progress.h>
 #include <glom/utility_widgets/dialog_image_save_progress.h>
+#include <libglom/utils.h>
+#include <libglom/file_utils.h>
 #include <gtkmm/appchooserdialog.h>
 #include <gtkmm/filechooserdialog.h>
-#include <giomm/file.h>
 #include <giomm/contenttype.h>
 #include <giomm/menu.h>
 #include <libgda/gda-blob-op.h>
@@ -166,10 +167,10 @@ bool ImageGlom::on_button_press_event(GdkEventButton *button_event)
   if(pApp)
   {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-    pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
-    pApp->add_developer_action(m_refContextAddField);
-    pApp->add_developer_action(m_refContextAddRelatedRecords);
-    pApp->add_developer_action(m_refContextAddGroup);
+    pApp->add_developer_action(m_context_layout); //So that it can be disabled when not in developer mode.
+    pApp->add_developer_action(m_context_add_field);
+    pApp->add_developer_action(m_context_add_related_records);
+    pApp->add_developer_action(m_context_add_group);
 
     pApp->update_userlevel_ui(); //Update our action's sensitivity.
 #endif // !GLOM_ENABLE_CLIENT_ONLY
@@ -220,11 +221,6 @@ AppWindow* ImageGlom::get_appwindow() const
   return dynamic_cast<AppWindow*>(pWindow);
 }
 
-bool ImageGlom::get_has_original_data() const
-{
-  return true; //TODO.
-}
-
 /*
 void ImageGlom::set_pixbuf(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf)
 {
@@ -293,7 +289,7 @@ const GdaBinary* ImageGlom::get_binary() const
   else if(m_original_data.get_value_type() == GDA_TYPE_BLOB)
   {
     const auto gda_blob = gda_value_get_blob(m_original_data.gobj());
-    if(gda_blob && gda_blob_op_read_all(const_cast<GdaBlobOp*>(gda_blob->op), const_cast<GdaBlob*>(gda_blob)))
+    if(gda_blob && gda_blob_op_read_all(gda_blob->op, const_cast<GdaBlob*>(gda_blob)))
       gda_binary = &(gda_blob->data);
   }
   
@@ -616,7 +612,7 @@ static void make_file_read_only(const Glib::ustring& uri)
 
 Glib::ustring ImageGlom::save_to_temp_file(bool show_progress)
 {
-  Glib::ustring uri = Utils::get_temp_file_uri("glom_image");
+  Glib::ustring uri = FileUtils::get_temp_file_uri("glom_image");
   if(uri.empty())
   {
     std::cerr << G_STRFUNC << ": : uri is empty.\n";
@@ -945,30 +941,30 @@ void ImageGlom::on_menupopup_activate_clear()
 void ImageGlom::setup_menu_usermode()
 {
   //Create the Gio::ActionGroup and associate it with this widget:
-  m_refActionGroup_UserModePopup = Gio::SimpleActionGroup::create();
+  m_action_group_user_mode_popup = Gio::SimpleActionGroup::create();
 
-  m_refActionOpenFile = m_refActionGroup_UserModePopup->add_action("open-file",
+  m_action_open_file = m_action_group_user_mode_popup->add_action("open-file",
     sigc::mem_fun(*this, &ImageGlom::on_menupopup_activate_open_file) );
 
-  m_refActionOpenFileWith = m_refActionGroup_UserModePopup->add_action("open-fil-ewith",
+  m_action_open_file_with = m_action_group_user_mode_popup->add_action("open-fil-ewith",
     sigc::mem_fun(*this, &ImageGlom::on_menupopup_activate_open_file_with) );
     
-  m_refActionSaveFile = m_refActionGroup_UserModePopup->add_action("save-file",
+  m_action_save_file = m_action_group_user_mode_popup->add_action("save-file",
     sigc::mem_fun(*this, &ImageGlom::on_menupopup_activate_save_file) );
     
-  m_refActionSelectFile = m_refActionGroup_UserModePopup->add_action("select-file",
+  m_action_select_file = m_action_group_user_mode_popup->add_action("select-file",
     sigc::mem_fun(*this, &ImageGlom::on_menupopup_activate_select_file) );
 
-  m_refActionCopy = m_refActionGroup_UserModePopup->add_action("copy",
+  m_action_copy = m_action_group_user_mode_popup->add_action("copy",
     sigc::mem_fun(*this, &ImageGlom::on_menupopup_activate_copy) );
 
-  m_refActionPaste = m_refActionGroup_UserModePopup->add_action("paste",
+  m_action_paste = m_action_group_user_mode_popup->add_action("paste",
     sigc::mem_fun(*this, &ImageGlom::on_menupopup_activate_paste) );
 
-  m_refActionClear = m_refActionGroup_UserModePopup->add_action("clear",
+  m_action_clear = m_action_group_user_mode_popup->add_action("clear",
     sigc::mem_fun(*this, &ImageGlom::on_menupopup_activate_clear) );
 
-  insert_action_group("imagecontext", m_refActionGroup_UserModePopup);
+  insert_action_group("imagecontext", m_action_group_user_mode_popup);
 
 
   //Create the UI for the menu whose items will activate the actions,
@@ -982,8 +978,8 @@ void ImageGlom::setup_menu_usermode()
   menu->append(_("_Paste"), "context.paste");
   menu->append(_("_Clear"), "context.clear");
 
-  m_pMenuPopup_UserMode = std::make_unique<Gtk::Menu>(menu);
-  m_pMenuPopup_UserMode->attach_to_widget(*this);
+  m_menu_popup_user_mode = std::make_unique<Gtk::Menu>(menu);
+  m_menu_popup_user_mode->attach_to_widget(*this);
 }
 
 void ImageGlom::do_choose_image()
@@ -998,15 +994,15 @@ void ImageGlom::set_read_only(bool read_only)
 
 void ImageGlom::popup_menu(guint button, guint32 activate_time)
 {
-  if(!m_pMenuPopup_UserMode)
+  if(!m_menu_popup_user_mode)
   {
-    std::cerr << G_STRFUNC << ": m_pMenuPopup_UserMode is null\n";
+    std::cerr << G_STRFUNC << ": m_menu_popup_user_mode is null\n";
     return;
   }
 
-  m_pMenuPopup_UserMode->popup(button, activate_time);
+  m_menu_popup_user_mode->popup(button, activate_time);
 
-  m_refActionSelectFile->set_enabled();
+  m_action_select_file->set_enabled();
 }
 
 
