@@ -50,16 +50,16 @@ private:
   NotebookGlom* m_notebook;
   
   void setup_menu(Gtk::Widget* widget);
-  std::unique_ptr<Gtk::Menu> m_pPopupMenu;
+  std::unique_ptr<Gtk::Menu> m_popup_menu;
   
   void on_menu_new_group_activate();
   void on_menu_delete_activate();
     
   bool on_button_press_event(GdkEventButton *event) override;
   
-  Glib::RefPtr<Gio::SimpleAction> m_refNewGroup;
-  Glib::RefPtr<Gio::SimpleAction> m_refDelete;  
-  Glib::RefPtr<Gio::SimpleActionGroup> m_refActionGroup;
+  Glib::RefPtr<Gio::SimpleAction> m_new_group;
+  Glib::RefPtr<Gio::SimpleAction> m_deelete;
+  Glib::RefPtr<Gio::SimpleActionGroup> m_action_group;
 };
 
 } //namespace Glom
