@@ -22,6 +22,7 @@
 
 #include <glom/utils_ui.h>
 #include <glom/appwindow.h>
+#include <libglom/utils.h>
 #include <libglom/connectionpool.h>
 #include <libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
 #include <libglom/data_structure/glomconversions.h>
@@ -34,21 +35,9 @@
 #include <glibmm/convert.h>
 #include <glibmm/miscutils.h>
 #include <glibmm/fileutils.h>
-
-#include <giomm/file.h>
 #include <glibmm/main.h>
 #include <glibmm/i18n.h>
-
-#include <string.h> // for strchr
-#include <sstream> //For stringstream
-
-#include <iostream>
-#include <fstream>
-
-#include <locale>     // for locale, time_put
-#include <ctime>     // for struct tm
 #include <iostream>   // for cout, endl
-#include <iomanip>
 
 #include <stack>
 
@@ -234,7 +223,7 @@ Glib::RefPtr<Gdk::Pixbuf> UiUtils::get_pixbuf_for_gda_value(const Gnome::Gda::Va
     if(buffer_binary && buffer_binary_length)
     {
       //typedef std::list<Gdk::PixbufFormat> type_list_formats;
-      //const type_list_formats formats = Gdk::Pixbuf::get_formats();
+      //const auto formats = Gdk::Pixbuf::get_formats();
       //std::cout << "Debug: Supported pixbuf formats:\n";
       //for(const auto& item : formats)
       //{
