@@ -21,6 +21,7 @@
 #include "tests/test_utils.h"
 #include <libglom/document/document.h>
 #include <libglom/init.h>
+#include <libglom/utils.h>
 #include <giomm/file.h>
 #include <glibmm/convert.h>
 #include <glibmm/miscutils.h>
@@ -64,7 +65,7 @@ int main()
 
   try
   {
-    const std::string path =
+    const auto path =
       Glib::build_filename(GLOM_DOCDIR_EXAMPLES_NOTINSTALLED,
         "example_smallbusiness.glom");
     uri = Glib::filename_to_uri(path);
