@@ -156,7 +156,7 @@ int main()
 
   try
   {
-    const std::string path =
+    const auto path =
        Glib::build_filename(GLOM_DOCDIR_EXAMPLES_NOTINSTALLED,
          "example_film_manager.glom");
     uri = Glib::filename_to_uri(path);
