@@ -19,6 +19,7 @@
  */
 
 #include "tests/test_selfhosting_utils.h"
+#include <libglom/algorithms_utils.h>
 #include <libglom/init.h>
 #include <libglom/utils.h>
 #include <libglom/db_utils.h>
@@ -31,23 +32,21 @@
 template<typename T_Container, typename T_Value>
 bool contains(const T_Container& container, const T_Value& name)
 {
-  typename T_Container::const_iterator iter =
-    std::find(container.begin(), container.end(), name);
-  return iter != container.end();
+  return Glom::Utils::find_exists(container, name);
 }
 
-static bool test_add_group(const Glom::Document& document, const Glib::ustring& group)
+static bool test_add_group(const std::shared_ptr<Glom::Document>& document, const Glib::ustring& group)
 {
-  if(!Glom::DbUtils::add_group(&document, group))
+  if(!Glom::DbUtils::add_group(document, group))
   {
-    std::cerr << G_STRFUNC << ": DbUtils::add_group() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": DbUtils::add_group() failed.\n";
     return false;
   }
 
   const auto group_list = Glom::Privs::get_database_groups();
   if(!contains(group_list, group))
   {
-    std::cerr << G_STRFUNC << ": Privs::get_database_groups() does not contain the expected group." << std::endl;
+    std::cerr << G_STRFUNC << ": Privs::get_database_groups() does not contain the expected group.\n";
     std::cerr << G_STRFUNC << ":   group: " << group << std::endl;
     return false;
   }
@@ -55,19 +54,19 @@ static bool test_add_group(const Glom::Document& document, const Glib::ustring&
   const auto user_list = Glom::Privs::get_database_users(group);
   if(!user_list.empty())
   {
-    std::cerr << G_STRFUNC << ": The user list is not empty as expected.." << std::endl;
+    std::cerr << G_STRFUNC << ": The user list is not empty as expected..\n";
     return false;
   }
 
   return true;
 }
 
-static bool test_add_user(const Glom::Document& document, const Glib::ustring& user, const Glib::ustring& group)
+static bool test_add_user(const std::shared_ptr<Glom::Document>& document, const Glib::ustring& user, const Glib::ustring& group)
 {
   //Add an operator user, adding it to the group:
-  if(!Glom::DbUtils::add_user(&document, user, "somepassword", group))
+  if(!Glom::DbUtils::add_user(document, user, "somepassword", group))
   {
-    std::cerr << G_STRFUNC << ": DbUtils::add_user() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": DbUtils::add_user() failed.\n";
     test_selfhosting_cleanup();
     return false;
   }
@@ -75,7 +74,7 @@ static bool test_add_user(const Glom::Document& document, const Glib::ustring& u
   const auto user_list = Glom::Privs::get_database_users(group);
   if(!contains(user_list, user))
   {
-    std::cerr << G_STRFUNC << ": Privs::get_database_users() does not contain the expected user:" << std::endl;
+    std::cerr << G_STRFUNC << ": Privs::get_database_users() does not contain the expected user:\n";
     std::cerr << G_STRFUNC << ":   group: " << group << std::endl;
     std::cerr << G_STRFUNC << ":   user: " << user << std::endl;
     return false;
@@ -123,10 +122,10 @@ static bool test(Glom::Document::HostingMode hosting_mode)
   }
 
   //Create and self-host the document:
-  Glom::Document document;
+  auto document = std::make_shared<Glom::Document>();
     if(!(test_create_and_selfhost_new_database(document, hosting_mode, "test_db")))
   {
-    std::cerr << G_STRFUNC << ": test_create_and_selfhost_new_database() failed" << std::endl;
+    std::cerr << G_STRFUNC << ": test_create_and_selfhost_new_database() failed\n";
     return false;
   }
 
@@ -142,15 +141,15 @@ static bool test(Glom::Document::HostingMode hosting_mode)
   //MySQL has a 64-character limit on SQL identifiers:
   if(hosting_mode != Glom::Document::HostingMode::MYSQL_SELF)
   {
-    table_names.push_back("sometablewithaverylongnameyaddayaddayaddayaddayaddyaddayaddayaddayaddayaddayaddayaddayaddayaddayaddayaddayadda");
+    table_names.emplace_back("sometablewithaverylongnameyaddayaddayaddayaddayaddyaddayaddayaddayaddayaddayaddayaddayaddayaddayaddayaddayadda");
   }
 
   //Add some tables, for the groups to have rights for:
   for(const auto& table_name : table_names)
   {
-    if(!Glom::DbUtils::create_table_with_default_fields(&document, table_name))
+    if(!Glom::DbUtils::create_table_with_default_fields(document, table_name))
     {
-      std::cerr << G_STRFUNC << ": Failure: create_table_with_default_fields() failed." << std::endl;
+      std::cerr << G_STRFUNC << ": Failure: create_table_with_default_fields() failed.\n";
       return false;
     }
   }
@@ -168,13 +167,13 @@ static bool test(Glom::Document::HostingMode hosting_mode)
   const auto group_list_original = Glom::Privs::get_database_groups();
   if(group_list_original.empty())
   {
-    std::cerr << G_STRFUNC << ": Privs::get_database_groups() returned an empty list." << std::endl;
+    std::cerr << G_STRFUNC << ": Privs::get_database_groups() returned an empty list.\n";
     return false;
   }
 
   if(!contains(group_list_original, GLOM_STANDARD_GROUP_NAME_DEVELOPER))
   {
-    std::cerr << G_STRFUNC << ": Privs::get_database_groups() does not contain the developers group." << std::endl;
+    std::cerr << G_STRFUNC << ": Privs::get_database_groups() does not contain the developers group.\n";
     return false;
   }
 
@@ -187,7 +186,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
     "somegroup with a ' quote character",
      "somegroupwithaverylongnameyaddayaddayaddayaddayaddyaddayaddayad"} ); //Almost too big.
   //We expect this to fail because of an apparently-undocumented max pg_user size of 63 characters in PostgreSQL:
-  //group_names.push_back("somegroupwithaverylongnameyaddayaddayaddayaddayaddyaddayaddayadd");
+  //group_names.emplace_back("somegroupwithaverylongnameyaddayaddayaddayaddayaddyaddayaddayadd");
 
   //Add groups:
   for(const auto& group_name : group_names)
@@ -207,7 +206,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
     "someuser with a ' quote character",
     "someuserwithaverylongnameyaddayaddayaddayaddayaddyaddayadda"} ); //Almost too big, with space for the numeric suffix below.
   //We expect this to fail because of an apparently-undocumented max pg_user size of 63 characters in PostgreSQL:
-  //user_names.push_back("someuserwithaverylongnameyaddayaddayaddayaddayaddyaddayaddayadd");
+  //user_names.emplace_back("someuserwithaverylongnameyaddayaddayaddayaddayaddyaddayaddayadd");
 
   guint i = 0;
   for(const auto& user_name : user_names)
