@@ -20,7 +20,7 @@
 
 #include "tests/test_selfhosting_utils.h"
 #include <libglom/init.h> 
-#include <libglom/utils.h>  
+#include <libglom/file_utils.h>
 #include <glib.h> //For g_assert()
 #include <iostream>
 #include <cstdlib> //For EXIT_SUCCESS and EXIT_FAILURE
@@ -47,7 +47,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
       return false;
     }
 
-    const auto backup_uri = Glom::Utils::get_temp_directory_uri();
+    const auto backup_uri = Glom::FileUtils::get_temp_directory_uri();
     backup_uri_tarball = document->save_backup_file(
       backup_uri,
       sigc::ptr_fun(&on_backup_progress));
