@@ -26,6 +26,8 @@
 #include <libglom/init.h>
 #include <libglom/privs.h>
 #include <libglom/db_utils.h>
+#include <libglom/file_utils.h>
+#include <libglom/sql_utils.h>
 #include <libglom/utils.h>
 #include <giomm/file.h>
 #include <glibmm/convert.h>
@@ -185,7 +187,7 @@ bool test_create_and_selfhost_new_empty(const std::shared_ptr<Glom::Document>& d
   //For instance, /tmp/testglom/testglom.glom");
   const std::string temp_filename = "testglom";
   temp_filepath_dir = 
-    Glom::Utils::get_temp_directory_path(temp_filename);
+    Glom::FileUtils::get_temp_directory_path(temp_filename);
   if(!subdirectory_path.empty())
     temp_filepath_dir = Glib::build_filename(temp_filepath_dir, subdirectory_path);
   const auto temp_filepath = Glib::build_filename(temp_filepath_dir, temp_filename);
@@ -218,7 +220,7 @@ bool test_create_and_selfhost_new_empty(const std::shared_ptr<Glom::Document>& d
   connection_pool->set_password(password);
 
   //Create the self-hosting files:
-  const Glom::ConnectionPool::InitErrors initialized_errors =
+  const auto initialized_errors =
     connection_pool->initialize( sigc::ptr_fun(&on_initialize_progress) );
   g_assert(initialized_errors == Glom::ConnectionPool::Backend::InitErrors::NONE);
   
@@ -418,7 +420,7 @@ bool test_model_expected_size(const Glib::RefPtr<const Gnome::Gda::DataModel>& d
 bool test_table_exists(const Glib::ustring& table_name, const std::shared_ptr<Glom::Document>& document)
 {
   //Try to get more rows than intended:
-  Glom::Utils::type_vecLayoutFields fieldsToGet;
+  Glom::SqlUtils::type_vecLayoutFields fieldsToGet;
   auto field = document->get_field_primary_key(table_name); //To to get some field.
   if(!field)
   {
@@ -431,7 +433,7 @@ bool test_table_exists(const Glib::ustring& table_name, const std::shared_ptr<Gl
   fieldsToGet.emplace_back(layoutitem);
 
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder = 
-    Glom::Utils::build_sql_select_with_where_clause(table_name,
+    Glom::SqlUtils::build_sql_select_with_where_clause(table_name,
       fieldsToGet);
   const Glib::RefPtr<const Gnome::Gda::DataModel> data_model = 
     Glom::DbUtils::query_execute_select(builder);
@@ -452,7 +454,7 @@ static bool test_example_musiccollection_data_related(const std::shared_ptr<cons
     return false;
   }
 
-  Glom::Utils::type_vecLayoutFields fieldsToGet;
+  Glom::SqlUtils::type_vecLayoutFields fieldsToGet;
 
   //Normal fields:
   auto field_album_id = document->get_field("albums", "album_id");
@@ -488,13 +490,13 @@ static bool test_example_musiccollection_data_related(const std::shared_ptr<cons
   fieldsToGet.emplace_back(layoutitem);
 
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder =
-    Glom::Utils::build_sql_select_with_key("albums", fieldsToGet, field_album_id, album_id);
+    Glom::SqlUtils::build_sql_select_with_key("albums", fieldsToGet, field_album_id, album_id);
   const Glib::RefPtr<const Gnome::Gda::DataModel> data_model = 
     Glom::DbUtils::query_execute_select(builder);
   if(!test_model_expected_size(data_model, 3, 1))
   {
     std::cerr << G_STRFUNC << ": Failure: Unexpected data model size with query: " << 
-      Glom::Utils::sqlbuilder_get_full_query(builder) << std::endl;
+      Glom::SqlUtils::sqlbuilder_get_full_query(builder) << std::endl;
     return false;
   }
   
@@ -512,9 +514,9 @@ bool test_example_musiccollection_data(const std::shared_ptr<const Glom::Documen
   //Check that some data is as expected:
   const Gnome::Gda::Value value("Born To Run");
   const Gnome::Gda::SqlExpr where_clause = 
-    Glom::Utils::get_find_where_clause_quick(document, "albums", value);
+    Glom::SqlUtils::get_find_where_clause_quick(document, "albums", value);
   
-  Glom::Utils::type_vecLayoutFields fieldsToGet;
+  Glom::SqlUtils::type_vecLayoutFields fieldsToGet;
   auto field = document->get_field("albums", "album_id");
   auto layoutitem = std::make_shared<Glom::LayoutItem_Field>();
   layoutitem->set_full_field_details(field);
@@ -531,14 +533,14 @@ bool test_example_musiccollection_data(const std::shared_ptr<const Glom::Documen
   fieldsToGet.emplace_back(layoutitem);
 
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder = 
-    Glom::Utils::build_sql_select_with_where_clause("albums",
+    Glom::SqlUtils::build_sql_select_with_where_clause("albums",
       fieldsToGet, where_clause);
   const Glib::RefPtr<const Gnome::Gda::DataModel> data_model = 
     Glom::DbUtils::query_execute_select(builder);
   if(!test_model_expected_size(data_model, 2, 1))
   {
     std::cerr << G_STRFUNC << "Failure: Unexpected data model size with query: " << 
-      Glom::Utils::sqlbuilder_get_full_query(builder) << std::endl;
+      Glom::SqlUtils::sqlbuilder_get_full_query(builder) << std::endl;
     return false;
   }
 
